@@ -52,7 +52,6 @@ def main():
         'src/toil/batchSystems/slurm.py',
         'src/toil/batchSystems/gridengine.py',
         'src/toil/batchSystems/singleMachine.py',
-        'src/toil/batchSystems/abstractBatchSystem.py',
         'src/toil/batchSystems/parasol.py',
         'src/toil/batchSystems/kubernetes.py',
         'src/toil/batchSystems/torque.py',
@@ -68,9 +67,6 @@ def main():
         'src/toil/batchSystems/mesos/conftest.py',
         'src/toil/batchSystems/mesos/__init__.py',
         'src/toil/batchSystems/mesos/test/__init__.py',
-        'src/toil/cwl/conftest.py',
-        'src/toil/cwl/__init__.py',
-        'src/toil/cwl/cwltoil.py',
         'src/toil/fileStores/cachingFileStore.py',
         'src/toil/jobStores/utils.py',
         'src/toil/jobStores/conftest.py',
@@ -97,19 +93,18 @@ def main():
         'src/toil/lib/encryption/conftest.py',
         'src/toil/lib/encryption/__init__.py',
         'src/toil/lib/aws/__init__.py',
+        'src/toil/server/utils.py',
+        'src/toil/server/wes/tasks.py',
+        'src/toil/utils/toilStats.py'
     ]]
 
     filtered_files_to_check = []
     for file_path in all_files_to_check:
         if file_path not in ignore_paths and 'src/toil/test' not in file_path:
             filtered_files_to_check.append(file_path)
-    # follow-imports type checks pypi projects we don't control, so we skip it; why is this their default?
-    args = ['mypy', '--follow-imports=skip'] + filtered_files_to_check
-    p = subprocess.run(args=args, stdout=subprocess.PIPE)
-    result = p.stdout.decode()
-    print(result)
-    if 'Success: no issues found' not in result:
-        exit(1)
+    args = ['mypy', '--color-output'] + filtered_files_to_check
+    p = subprocess.run(args=args)
+    exit(p.returncode)
 
 
 if __name__ == '__main__':
