@@ -20,6 +20,7 @@ import subprocess
 import sys
 import time
 from datetime import datetime
+from typing import TYPE_CHECKING
 
 import requests
 from pytz import timezone
@@ -29,6 +30,9 @@ from toil.lib.memoize import memoize
 from toil.lib.retry import retry
 from toil.version import currentCommit
 
+if TYPE_CHECKING:
+    from toil.common import Config
+
 log = logging.getLogger(__name__)
 
 
@@ -99,9 +103,10 @@ def which(cmd, mode=os.F_OK | os.X_OK, path=None):
     return None
 
 
-def toilPackageDirPath():
+def toilPackageDirPath() -> str:
     """
-    Returns the absolute path of the directory that corresponds to the top-level toil package.
+    Return the absolute path of the directory that corresponds to the top-level toil package.
+
     The return value is guaranteed to end in '/toil'.
     """
     result = os.path.dirname(os.path.realpath(__file__))
@@ -161,7 +166,7 @@ def physicalDisk(directory: str) -> int:
     return diskStats.f_frsize * diskStats.f_bavail
 
 
-def applianceSelf(forceDockerAppliance=False):
+def applianceSelf(forceDockerAppliance: bool = False) -> str:
     """
     Returns the fully qualified name of the Docker image to start Toil appliance containers from.
     The result is determined by the current version of Toil and three environment variables:
@@ -355,8 +360,11 @@ class ApplianceImageNotFound(ImageNotFound):
                "'quay.io/ucsc_cgl/toil:latest', 'ubuntu:latest', or "
                "'broadinstitute/genomes-in-the-cloud:2.0.0'."
                "" % (origAppliance, url, str(statusCode)))
-        super(ApplianceImageNotFound, self).__init__(msg)
+        super().__init__(msg)
 
+# Cache images we know exist so we don't have to ask the registry about them
+# all the time.
+KNOWN_EXTANT_IMAGES = set()
 
 def requestCheckRegularDocker(origAppliance, registryName, imageName, tag):
     """
@@ -379,12 +387,18 @@ def requestCheckRegularDocker(origAppliance, registryName, imageName, tag):
     :param str tag: The tag used at that docker image's registry.  e.g. "latest"
     :return: Return True if match found.  Raise otherwise.
     """
+
+    if origAppliance in KNOWN_EXTANT_IMAGES:
+        # Check the cache first
+        return origAppliance
+
     ioURL = 'https://{webhost}/v2/{pathName}/manifests/{tag}' \
             ''.format(webhost=registryName, pathName=imageName, tag=tag)
     response = requests.head(ioURL)
     if not response.ok:
         raise ApplianceImageNotFound(origAppliance, ioURL, response.status_code)
     else:
+        KNOWN_EXTANT_IMAGES.add(origAppliance)
         return origAppliance
 
 
@@ -400,25 +414,31 @@ def requestCheckDockerIo(origAppliance, imageName, tag):
     :param str tag: The tag used at that docker image's registry.  e.g. "latest"
     :return: Return True if match found.  Raise otherwise.
     """
+
+    if origAppliance in KNOWN_EXTANT_IMAGES:
+        # Check the cache first
+        return origAppliance
+
     # only official images like 'busybox' or 'ubuntu'
     if '/' not in imageName:
         imageName = 'library/' + imageName
 
     token_url = 'https://auth.docker.io/token?service=registry.docker.io&scope=repository:{repo}:pull'.format(
         repo=imageName)
-    requests_url = 'https://registry-1.docker.io/v2/{repo}/manifests/{tag}'.format(repo=imageName, tag=tag)
+    requests_url = f'https://registry-1.docker.io/v2/{imageName}/manifests/{tag}'
 
     token = requests.get(token_url)
     jsonToken = token.json()
     bearer = jsonToken["token"]
-    response = requests.head(requests_url, headers={'Authorization': 'Bearer {}'.format(bearer)})
+    response = requests.head(requests_url, headers={'Authorization': f'Bearer {bearer}'})
     if not response.ok:
         raise ApplianceImageNotFound(origAppliance, requests_url, response.status_code)
     else:
+        KNOWN_EXTANT_IMAGES.add(origAppliance)
         return origAppliance
 
 
-def logProcessContext(config):
+def logProcessContext(config: "Config") -> None:
     # toil.version.version (string) cannot be imported at top level because it conflicts with
     # toil.version (module) and Sphinx doesn't like that.
     from toil.version import version
@@ -503,7 +523,7 @@ try:
                 self._boto3_resolver = None
 
             # Pass along all the arguments
-            super(BotoCredentialAdapter, self).__init__(name, access_key=access_key,
+            super().__init__(name, access_key=access_key,
                                                         secret_key=secret_key, security_token=security_token,
                                                         profile_name=profile_name, **kwargs)
 
@@ -521,7 +541,7 @@ try:
             else:
                 # We're not on AWS, or they passed a key, or we're anonymous.
                 # Use the normal route; our credentials shouldn't expire.
-                super(BotoCredentialAdapter, self).get_credentials(access_key=access_key,
+                super().get_credentials(access_key=access_key,
                                                                    secret_key=secret_key, security_token=security_token,
                                                                    profile_name=profile_name)
 
@@ -598,7 +618,7 @@ try:
             while True:
                 log.debug('Attempting to read cached credentials from %s.', path)
                 try:
-                    with open(path, 'r') as f:
+                    with open(path) as f:
                         content = f.read()
                         if content:
                             record = content.split('\n')
@@ -611,7 +631,7 @@ try:
                             log.debug('%s is empty. Credentials are not temporary.', path)
                             self._obtain_credentials_from_boto3()
                             return
-                except IOError as e:
+                except OSError as e:
                     if e.errno == errno.ENOENT:
                         log.debug('Cached credentials are missing.')
                         dir_path = os.path.dirname(path)
