@@ -32,21 +32,23 @@ import sys
 import tempfile
 import time
 import uuid
-from typing import Optional, Dict
+import yaml
+from argparse import ArgumentParser, _ArgumentGroup
+from typing import Any, Callable, Dict, List, Optional, TypeVar, Union
 
 import kubernetes
-import pytz
 import urllib3
 from kubernetes.client.rest import ApiException
 
 from toil import applianceSelf
 from toil.batchSystems.abstractBatchSystem import (EXIT_STATUS_UNAVAILABLE_VALUE,
                                                    BatchJobExitReason,
-                                                   BatchSystemCleanupSupport,
                                                    UpdatedBatchJobInfo)
+from toil.batchSystems.cleanup_support import BatchSystemCleanupSupport
 from toil.common import Toil
 from toil.job import JobDescription
 from toil.lib.conversions import human2bytes
+from toil.lib.misc import slow_down, utc_now
 from toil.lib.retry import ErrorCondition, retry
 from toil.resource import Resource
 from toil.statsAndLogging import configure_root_logger, set_log_level
@@ -68,35 +70,13 @@ def is_retryable_kubernetes_error(e):
     return False
 
 
-def slow_down(seconds):
-    """
-    Toil jobs that have completed are not allowed to have taken 0 seconds, but
-    Kubernetes timestamps round things to the nearest second. It is possible in Kubernetes for
-    a pod to have identical start and end timestamps.
-
-    This function takes a possibly 0 job length in seconds and enforces a minimum length to satisfy Toil.
-
-    :param float seconds: Kubernetes timestamp difference
-
-    :return: seconds, or a small positive number if seconds is 0
-    :rtype: float
-    """
-
-    return max(seconds, sys.float_info.epsilon)
-
-
-def utc_now():
-    """Return a datetime in the UTC timezone corresponding to right now."""
-    return datetime.datetime.utcnow().replace(tzinfo=pytz.UTC)
-
-
 class KubernetesBatchSystem(BatchSystemCleanupSupport):
     @classmethod
     def supportsAutoDeployment(cls):
         return True
 
     def __init__(self, config, maxCores, maxMemory, maxDisk):
-        super(KubernetesBatchSystem, self).__init__(config, maxCores, maxMemory, maxDisk)
+        super().__init__(config, maxCores, maxMemory, maxDisk)
 
         # Turn down log level for Kubernetes modules and dependencies.
         # Otherwise if we are at debug log level, we dump every
@@ -113,32 +93,34 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
         # Get our namespace (and our Kubernetes credentials to make sure they exist)
         self.namespace = self._api('namespace')
 
-        # Decide if we are going to mount a Kubernetes host path as /tmp in the workers.
-        # If we do this and the work dir is the default of the temp dir, caches will be shared.
-        self.host_path = config.kubernetesHostPath
-        if self.host_path is None and os.environ.get("TOIL_KUBERNETES_HOST_PATH", None) is not None:
-            # We can also take it from an environment variable
-            self.host_path = os.environ.get("TOIL_KUBERNETES_HOST_PATH")
+        # Decide if we are going to mount a Kubernetes host path as the Toil
+        # work dir in the workers, for shared caching.
+        self.host_path = config.kubernetes_host_path
 
-        # Make a Kubernetes-acceptable version of our username: not too long,
-        # and all lowercase letters, numbers, or - or .
-        acceptableChars = set(string.ascii_lowercase + string.digits + '-.')
-
-        # Use TOIL_KUBERNETES_OWNER if present in env var
-        if os.environ.get("TOIL_KUBERNETES_OWNER", None) is not None:
-            username = os.environ.get("TOIL_KUBERNETES_OWNER")
-        else:
-            username = ''.join([c for c in getpass.getuser().lower() if c in acceptableChars])[:100]
+        # Get the service account name to use, if any.
+        self.service_account = config.kubernetes_service_account
 
+        # Get the username to mark jobs with
+        username = config.kubernetes_owner
+        # And a unique ID for the run
         self.uniqueID = uuid.uuid4()
 
         # Create a prefix for jobs, starting with our username
-        self.jobPrefix = '{}-toil-{}-'.format(username, self.uniqueID)
-
+        self.jobPrefix = f'{username}-toil-{self.uniqueID}-'
         # Instead of letting Kubernetes assign unique job names, we assign our
         # own based on a numerical job ID. This functionality is managed by the
         # BatchSystemLocalSupport.
 
+        # The UCSC GI Kubernetes cluster (and maybe other clusters?) appears to
+        # relatively promptly destroy finished jobs for you if they don't
+        # specify a ttlSecondsAfterFinished. This leads to "lost" Toil jobs,
+        # and (if your workflow isn't allowed to run longer than the default
+        # lost job recovery interval) timeouts of e.g. CWL Kubernetes
+        # conformance tests. To work around this, we tag all our jobs with an
+        # explicit TTL that is long enough that we're sure we can deal with all
+        # the finished jobs before they expire.
+        self.finished_job_ttl = 3600  # seconds
+
         # Here is where we will store the user script resource object if we get one.
         self.userScript = None
 
@@ -158,17 +140,48 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
             self.workerWorkDir = '/var/lib/toil'
 
         # Get the name of the AWS secret, if any, to mount in containers.
-        # TODO: have some way to specify this (env var?)!
         self.awsSecretName = os.environ.get("TOIL_AWS_SECRET_NAME", None)
 
         # Set this to True to enable the experimental wait-for-job-update code
-        # TODO: Make this an environment variable?
         self.enableWatching = os.environ.get("KUBE_WATCH_ENABLED", False)
 
-        self.runID = 'toil-{}'.format(self.uniqueID)
+        # This will be a label to select all our jobs.
+        self.runID = f'toil-{self.uniqueID}'
 
-        self.jobIds = set()
+    def _pretty_print(self, kubernetes_object: Any) -> str:
+        """
+        Pretty-print a Kubernetes API object to a YAML string. Recursively
+        drops boring fields.
+        Takes any Kubernetes API object; not clear if any base type exists for
+        them.
+        """
 
+        if not kubernetes_object:
+            return 'None'
+
+        # We need a Kubernetes widget that knows how to translate
+        # its data structures to nice YAML-able dicts. See:
+        # <https://github.com/kubernetes-client/python/issues/1117#issuecomment-939957007>
+        api_client = kubernetes.client.ApiClient()
+
+        # Convert to a dict
+        root_dict = api_client.sanitize_for_serialization(kubernetes_object)
+
+        def drop_boring(here):
+            """
+            Drop boring fields recursively.
+            """
+            boring_keys = []
+            for k, v in here.items():
+                if isinstance(v, dict):
+                    drop_boring(v)
+                if k in ['managedFields']:
+                    boring_keys.append(k)
+            for k in boring_keys:
+                del here[k]
+
+        drop_boring(root_dict)
+        return yaml.dump(root_dict)
 
     def _api(self, kind, max_age_seconds = 5 * 60):
         """
@@ -222,7 +235,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
             # We just need the namespace string
             if config_source == 'in_cluster':
                 # Our namespace comes from a particular file.
-                with open("/var/run/secrets/kubernetes.io/serviceaccount/namespace", 'r') as fh:
+                with open("/var/run/secrets/kubernetes.io/serviceaccount/namespace") as fh:
                     return fh.read().strip()
             else:
                 # Find all contexts and the active context.
@@ -239,7 +252,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
             try:
                 return self._apis[kind]
             except KeyError:
-                raise RuntimeError("Unknown Kubernetes API type: {}".format(kind))
+                raise RuntimeError(f"Unknown Kubernetes API type: {kind}")
 
     @retry(errors=retryable_kubernetes_errors)
     def _try_kubernetes(self, method, *args, **kwargs):
@@ -316,7 +329,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
 
 
     def setUserScript(self, userScript):
-        logger.info('Setting user script for deployment: {}'.format(userScript))
+        logger.info(f'Setting user script for deployment: {userScript}')
         self.userScript = userScript
 
     # setEnv is provided by BatchSystemSupport, updates self.environment
@@ -378,6 +391,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
 
         # Make a job dict to send to the executor.
         # First just wrap the command and the environment to run it in
+        # TODO: send environment via pod spec
         job = {'command': jobDesc.command,
                'environment': environment}
         # TODO: query customDockerInitCmd to respect TOIL_CUSTOM_DOCKER_INIT_COMMAND
@@ -451,7 +465,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
             mounts.append(secret_volume_mount)
 
         # Make a container definition
-        container = kubernetes.client.V1Container(command=['_toil_kubernetes_executor', encodedJob],
+        container = kubernetes.client.V1Container(command=['_toil_contained_executor', encodedJob],
                                                   image=self.dockerImage,
                                                   name="runner-container",
                                                   resources=resources,
@@ -463,6 +477,10 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
         # Tell the spec where to land
         pod_spec.affinity = self._create_affinity(jobDesc.preemptable)
 
+        if self.service_account:
+            # Apply service account if set
+            pod_spec.service_account_name = self.service_account
+
         return pod_spec
 
     def issueBatchJob(self, jobDesc, job_environment: Optional[Dict[str, str]] = None):
@@ -497,8 +515,12 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
             # Wrap the spec in a template
             template = kubernetes.client.V1PodTemplateSpec(spec=pod_spec, metadata=metadata)
 
-            # Make another spec for the job, asking to run the template with no backoff
-            job_spec = kubernetes.client.V1JobSpec(template=template, backoff_limit=0)
+            # Make another spec for the job, asking to run the template with no
+            # backoff/retry. Specify our own TTL to avoid catching the notice
+            # of over-zealous abandoned job cleanup scripts.
+            job_spec = kubernetes.client.V1JobSpec(template=template,
+                                                   backoff_limit=0,
+                                                   ttl_seconds_after_finished=self.finished_job_ttl)
 
             # And make the actual job
             job = kubernetes.client.V1Job(spec=job_spec,
@@ -548,13 +570,11 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
 
             if onlySucceeded:
                 results =  self._try_kubernetes(self._api('batch').list_namespaced_job, self.namespace,
-                                                label_selector="toil_run={}".format(self.runID), field_selector="status.successful==1", **kwargs)
+                                                label_selector=f"toil_run={self.runID}", field_selector="status.successful==1", **kwargs)
             else:
                 results = self._try_kubernetes(self._api('batch').list_namespaced_job, self.namespace,
-                                                label_selector="toil_run={}".format(self.runID), **kwargs)
-            for job in results.items:
-                # This job belongs to us
-                yield job
+                                                label_selector=f"toil_run={self.runID}", **kwargs)
+            yield from results.items  # These jobs belong to us
 
             # Remember the continuation token, if any
             token = getattr(results.metadata, 'continue', None)
@@ -581,10 +601,9 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
             if token is not None:
                 kwargs['_continue'] = token
 
-            results = self._try_kubernetes(self._api('core').list_namespaced_pod, self.namespace, label_selector="toil_run={}".format(self.runID), **kwargs)
+            results = self._try_kubernetes(self._api('core').list_namespaced_pod, self.namespace, label_selector=f"toil_run={self.runID}", **kwargs)
 
-            for pod in results.items:
-                yield pod
+            yield from results.items
             # Remember the continuation token, if any
             token = getattr(results.metadata, 'continue', None)
 
@@ -610,7 +629,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
         # Work out what the return code was (which we need to get from the
         # pods) We get the associated pods by querying on the label selector
         # `job-name=JOBNAME`
-        query = 'job-name={}'.format(jobObject.metadata.name)
+        query = f'job-name={jobObject.metadata.name}'
 
         while True:
             # We can't just pass e.g. a None continue token when there isn't
@@ -758,7 +777,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
         # Otherwise we need to maybe wait.
         if self.enableWatching:
             for event in self._try_kubernetes_stream(self._api('batch').list_namespaced_job, self.namespace,
-                                                        label_selector="toil_run={}".format(self.runID),
+                                                        label_selector=f"toil_run={self.runID}",
                                                         timeout_seconds=maxWait):
                 # Grab the metadata data, ID, the list of conditions of the current job, and the total pods
                 jobObject = event['object']
@@ -786,7 +805,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
                     if jobObject.status.failed > 0:
                         exitReason = BatchJobExitReason.FAILED
                         pod = self._getPodForJob(jobObject)
-                        logger.debug("Failed job %s", str(jobObject))
+                        logger.debug("Failed job %s", self._pretty_print(jobObject))
                         logger.warning("Failed Job Message: %s", termination.message)
                         exitCode = pod.status.container_statuses[0].state.terminated.exit_code
 
@@ -795,6 +814,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
 
                     if (exitReason == BatchJobExitReason.FAILED) or (jobObject.status.finished == totalPods):
                         # Cleanup if job is all finished or there was a pod that failed
+                        logger.debug('Deleting Kubernetes job %s', jobObject.metadata.name)
                         self._try_kubernetes(self._api('batch').delete_namespaced_job,
                                             jobObject.metadata.name,
                                             self.namespace,
@@ -804,7 +824,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
                     continue
                 else:
                     # Job is not running/updating ; no active, successful, or failed pods yet
-                    logger.debug("Job %s -> %s" % (jobObject.metadata.name, jobObjectListConditions[0].reason))
+                    logger.debug("Job {} -> {}".format(jobObject.metadata.name, jobObjectListConditions[0].reason))
                     # Pod could be pending; don't say it's lost.
                     continue
         else:
@@ -912,6 +932,9 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
         if jobObject is None:
             # Say we couldn't find anything
             return None
+        else:
+            # We actually have something
+            logger.debug('Identified stopped Kubernetes job %s as %s', jobObject.metadata.name, chosenFor)
 
 
         # Otherwise we got something.
@@ -1001,6 +1024,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
 
         try:
             # Delete the job and all dependents (pods), hoping to get a 404 if it's magically gone
+            logger.debug('Deleting Kubernetes job %s', jobObject.metadata.name)
             self._try_kubernetes_expecting_gone(self._api('batch').delete_namespaced_job, jobObject.metadata.name,
                                                 self.namespace,
                                                 propagation_policy='Foreground')
@@ -1049,7 +1073,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
                 # It was a 404; the job is gone. Stop polling it.
                 break
 
-    def shutdown(self):
+    def shutdown(self) -> None:
 
         # Shutdown local processes first
         self.shutdownLocal()
@@ -1057,9 +1081,10 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
 
         # Kill all of our jobs and clean up pods that are associated with those jobs
         try:
+            logger.debug('Deleting all Kubernetes jobs for toil_run=%s', self.runID)
             self._try_kubernetes_expecting_gone(self._api('batch').delete_collection_namespaced_job,
                                                             self.namespace,
-                                                            label_selector="toil_run={}".format(self.runID),
+                                                            label_selector=f"toil_run={self.runID}",
                                                             propagation_policy='Background')
             logger.debug('Killed jobs with delete_collection_namespaced_job; cleaned up')
         except ApiException as e:
@@ -1073,14 +1098,14 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
             for pod in ourPods:
                 try:
                     if pod.status.phase == 'Failed':
-                            logger.debug('Failed pod encountered at shutdown: %s', str(pod))
+                            logger.debug('Failed pod encountered at shutdown:\n%s', self._pretty_print(pod))
                     if pod.status.phase == 'Orphaned':
-                            logger.debug('Orphaned pod encountered at shutdown: %s', str(pod))
+                            logger.debug('Orphaned pod encountered at shutdown:\n%s', self._pretty_print(pod))
                 except:
                     # Don't get mad if that doesn't work.
                     pass
                 try:
-                    logger.debug('Cleaning up pod at shutdown: %s', str(pod))
+                    logger.debug('Cleaning up pod at shutdown: %s', pod.metadata.name)
                     respone = self._try_kubernetes_expecting_gone(self._api('core').delete_namespaced_pod,  pod.metadata.name,
                                         self.namespace,
                                         propagation_policy='Background')
@@ -1150,6 +1175,7 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
 
             # Delete the requested job in the foreground.
             # This doesn't block, but it does delete expeditiously.
+            logger.debug('Deleting Kubernetes job %s', jobName)
             response = self._try_kubernetes(self._api('batch').delete_namespaced_job, jobName,
                                                                 self.namespace,
                                                                 propagation_policy='Foreground')
@@ -1164,67 +1190,34 @@ class KubernetesBatchSystem(BatchSystemCleanupSupport):
             # Block until it doesn't exist
             self._waitForJobDeath(jobName)
 
-def executor():
-    """
-    Main function of the _toil_kubernetes_executor entrypoint.
+    @classmethod
+    def get_default_kubernetes_owner(cls) -> str:
+        """
+        Get the default Kubernetes-acceptable username string to tack onto jobs.
+        """
 
-    Runs inside the Toil container.
+        # Make a Kubernetes-acceptable version of our username: not too long,
+        # and all lowercase letters, numbers, or - or .
+        acceptable_chars = set(string.ascii_lowercase + string.digits + '-.')
 
-    Responsible for setting up the user script and running the command for the
-    job (which may in turn invoke the Toil worker entrypoint).
+        return ''.join([c for c in getpass.getuser().lower() if c in acceptable_chars])[:100]
 
-    """
+    @classmethod
+    def add_options(cls, parser: Union[ArgumentParser, _ArgumentGroup]) -> None:
+        parser.add_argument("--kubernetesHostPath", dest="kubernetes_host_path", default=None,
+                            help="Path on Kubernetes hosts to use as shared inter-pod temp directory.  "
+                                 "(default: %(default)s)")
+        parser.add_argument("--kubernetesOwner", dest="kubernetes_owner", default=cls.get_default_kubernetes_owner(),
+                            help="Username to mark Kubernetes jobs with.  "
+                                 "(default: %(default)s)")
+        parser.add_argument("--kubernetesServiceAccount", dest="kubernetes_service_account", default=None,
+                            help="Service account to run jobs as.  "
+                                 "(default: %(default)s)")
 
-    configure_root_logger()
-    set_log_level("DEBUG")
-    logger.debug("Starting executor")
+    OptionType = TypeVar('OptionType')
+    @classmethod
+    def setOptions(cls, setOption: Callable[[str, Optional[Callable[[str], OptionType]], Optional[Callable[[OptionType], None]], Optional[OptionType], Optional[List[str]]], None]) -> None:
+        setOption("kubernetes_host_path", default=None, env=['TOIL_KUBERNETES_HOST_PATH'])
+        setOption("kubernetes_owner", default=cls.get_default_kubernetes_owner(), env=['TOIL_KUBERNETES_OWNER'])
+        setOption("kubernetes_service_account", default=None, env=['TOIL_KUBERNETES_SERVICE_ACCOUNT'])
 
-    # If we don't manage to run the child, what should our exit code be?
-    exit_code = EXIT_STATUS_UNAVAILABLE_VALUE
-
-    if len(sys.argv) != 2:
-        logger.error('Executor requires exactly one base64-encoded argument')
-        sys.exit(exit_code)
-
-    # Take in a base64-encoded pickled dict as our first argument and decode it
-    try:
-        # Make sure to encode the text arguments to bytes before base 64 decoding
-        job = pickle.loads(base64.b64decode(sys.argv[1].encode('utf-8')))
-    except:
-        exc_info = sys.exc_info()
-        logger.error('Exception while unpickling task: ', exc_info=exc_info)
-        sys.exit(exit_code)
-
-    if 'environment' in job:
-        # Adopt the job environment into the executor.
-        # This lets us use things like TOIL_WORKDIR when figuring out how to talk to other executors.
-        logger.debug('Adopting environment: %s', str(job['environment'].keys()))
-        for var, value in job['environment'].items():
-            os.environ[var] = value
-
-    # Set JTRES_ROOT and other global state needed for resource
-    # downloading/deployment to work.
-    # TODO: Every worker downloads resources independently.
-    # We should have a way to share a resource directory.
-    logger.debug('Preparing system for resource download')
-    Resource.prepareSystem()
-    try:
-        if 'userScript' in job:
-            job['userScript'].register()
-
-        # Start the child process
-        logger.debug("Invoking command: '%s'", job['command'])
-        child = subprocess.Popen(job['command'],
-                                 preexec_fn=lambda: os.setpgrp(),
-                                 shell=True)
-
-        # Reproduce child's exit code
-        exit_code = child.wait()
-
-    finally:
-        logger.debug('Cleaning up resources')
-        # TODO: Change resource system to use a shared resource directory for everyone.
-        # Then move this into worker cleanup somehow
-        Resource.cleanSystem()
-        logger.debug('Shutting down')
-        sys.exit(exit_code)
