@@ -22,9 +22,10 @@ import socket
 import sys
 import time
 import traceback
+from argparse import ArgumentParser, _ArgumentGroup
 from contextlib import contextmanager
 from queue import Empty, Queue
-from typing import Optional, Dict
+from typing import Dict, Optional, Union
 from urllib.parse import quote_plus
 from urllib.request import urlopen
 
@@ -35,12 +36,13 @@ from toil import resolveEntryPoint
 from toil.batchSystems.abstractBatchSystem import (EXIT_STATUS_UNAVAILABLE_VALUE,
                                                    AbstractScalableBatchSystem,
                                                    BatchJobExitReason,
-                                                   BatchSystemLocalSupport,
                                                    NodeInfo,
                                                    UpdatedBatchJobInfo)
+from toil.batchSystems.local_support import BatchSystemLocalSupport
 from toil.batchSystems.mesos import JobQueue, MesosShape, TaskData, ToilJob
 from toil.job import JobDescription
 from toil.lib.memoize import strict_bool
+from toil.lib.misc import get_public_ip
 
 log = logging.getLogger(__name__)
 
@@ -67,7 +69,7 @@ class MesosBatchSystem(BatchSystemLocalSupport,
     def supportsWorkerCleanup(cls):
         return True
 
-    class ExecutorInfo(object):
+    class ExecutorInfo:
         def __init__(self, nodeAddress, agentId, nodeInfo, lastSeen):
             super(MesosBatchSystem.ExecutorInfo, self).__init__()
             self.nodeAddress = nodeAddress
@@ -76,7 +78,7 @@ class MesosBatchSystem(BatchSystemLocalSupport,
             self.lastSeen = lastSeen
 
     def __init__(self, config, maxCores, maxMemory, maxDisk):
-        super(MesosBatchSystem, self).__init__(config, maxCores, maxMemory, maxDisk)
+        super().__init__(config, maxCores, maxMemory, maxDisk)
 
         # The auto-deployed resource representing the user script. Will be passed along in every
         # Mesos task. Also see setUserScript().
@@ -90,7 +92,7 @@ class MesosBatchSystem(BatchSystemLocalSupport,
         self.jobQueues = JobQueue()
 
         # Address of the Mesos master in the form host:port where host can be an IP or a hostname
-        self.mesosMasterAddress = config.mesosMasterAddress
+        self.mesos_endpoint = config.mesos_endpoint
 
         # Written to when Mesos kills tasks, as directed by Toil.
         # Jobs must not enter this set until they are removed from runningJobMap.
@@ -328,7 +330,7 @@ class MesosBatchSystem(BatchSystemLocalSupport,
         # Make the driver which implements most of the scheduler logic and calls back to us for the user-defined parts.
         # Make sure it will call us with nice namespace-y addicts
         self.driver = MesosSchedulerDriver(self, framework,
-                                           self._resolveAddress(self.mesosMasterAddress),
+                                           self._resolveAddress(self.mesos_endpoint),
                                            use_addict=True, implicit_acknowledgements=True)
         self.driver.start()
 
@@ -354,7 +356,7 @@ class MesosBatchSystem(BatchSystemLocalSupport,
         address[0] = socket.gethostbyname(address[0])
         return ':'.join(address)
 
-    def shutdown(self):
+    def shutdown(self) -> None:
         self.shutdownLocal()
         log.debug("Stopping Mesos driver")
         self.driver.stop()
@@ -828,9 +830,21 @@ class MesosBatchSystem(BatchSystemLocalSupport,
 
         self._handleFailedExecutor(agentId.value, failedId)
 
+    @classmethod
+    def get_default_mesos_endpoint(cls) -> str:
+        """
+        Get the default IP/hostname and port that we will look for Mesos at.
+        """
+        return f'{get_public_ip()}:5050'
+
+    @classmethod
+    def add_options(cls, parser: Union[ArgumentParser, _ArgumentGroup]) -> None:
+        parser.add_argument("--mesosEndpoint", "--mesosMaster", dest="mesos_endpoint", default=cls.get_default_mesos_endpoint(),
+                            help="The host and port of the Mesos master separated by colon.  (default: %(default)s)")
+
     @classmethod
     def setOptions(cls, setOption):
-        setOption("mesosMasterAddress", None, None, 'localhost:5050')
+        setOption("mesos_endpoint", None, None, cls.get_default_mesos_endpoint(), old_names=["mesosMasterAddress"])
 
 
 def toMiB(n):
