@@ -16,21 +16,21 @@ import math
 import os
 import signal
 import subprocess
-import sys
 import time
 import traceback
+from argparse import ArgumentParser, _ArgumentGroup
 from contextlib import contextmanager
 from queue import Empty, Queue
 from threading import Condition, Event, Lock, Thread
-from typing import Dict, List, Optional, Sequence
+from typing import Dict, List, Optional, Sequence, Union
 
 import toil
-import toil.job
 from toil import worker as toil_worker
 from toil.batchSystems.abstractBatchSystem import (EXIT_STATUS_UNAVAILABLE_VALUE,
                                                    BatchSystemSupport,
                                                    UpdatedBatchJobInfo)
-from toil.common import Toil
+from toil.common import SYS_MAX_SIZE, Config, Toil, fC
+from toil.job import JobDescription
 from toil.lib.threading import cpu_count
 
 log = logging.getLogger(__name__)
@@ -72,7 +72,9 @@ class SingleMachineBatchSystem(BatchSystemSupport):
     """
     physicalMemory = toil.physicalMemory()
 
-    def __init__(self, config, maxCores, maxMemory, maxDisk):
+    def __init__(
+        self, config: Config, maxCores: int, maxMemory: int, maxDisk: int
+    ) -> None:
         self.config = config
         # Limit to the smaller of the user-imposed limit and what we actually
         # have on this machine for each resource.
@@ -80,12 +82,12 @@ class SingleMachineBatchSystem(BatchSystemSupport):
         # If we don't have up to the limit of the resource (and the resource
         # isn't the inlimited sentinel), warn.
         if maxCores > self.numCores:
-            if maxCores != sys.maxsize:
+            if maxCores != SYS_MAX_SIZE:
                 # We have an actually specified limit and not the default
                 log.warning('Not enough cores! User limited to %i but we only have %i.', maxCores, self.numCores)
             maxCores = self.numCores
         if maxMemory > self.physicalMemory:
-            if maxMemory != sys.maxsize:
+            if maxMemory != SYS_MAX_SIZE:
                 # We have an actually specified limit and not the default
                 log.warning('Not enough memory! User limited to %i bytes but we only have %i bytes.', maxMemory, self.physicalMemory)
             maxMemory = self.physicalMemory
@@ -93,12 +95,12 @@ class SingleMachineBatchSystem(BatchSystemSupport):
         workdir = Toil.getLocalWorkflowDir(config.workflowID, config.workDir)  # config.workDir may be None; this sets a real directory
         self.physicalDisk = toil.physicalDisk(workdir)
         if maxDisk > self.physicalDisk:
-            if maxDisk != sys.maxsize:
+            if maxDisk != SYS_MAX_SIZE:
                 # We have an actually specified limit and not the default
                 log.warning('Not enough disk space! User limited to %i bytes but we only have %i bytes.', maxDisk, self.physicalDisk)
             maxDisk = self.physicalDisk
 
-        super(SingleMachineBatchSystem, self).__init__(config, maxCores, maxMemory, maxDisk)
+        super().__init__(config, maxCores, maxMemory, maxDisk)
         assert self.maxCores >= self.minCores
         assert self.maxMemory >= 1
 
@@ -119,8 +121,8 @@ class SingleMachineBatchSystem(BatchSystemSupport):
         self.jobIndex = 0
         self.jobIndexLock = Lock()
 
-        # A dictionary mapping IDs of submitted jobs to the command line
-        self.jobs: Dict[str, toil.job.JobDescription] = {}
+        # A dictionary mapping batch system IDs of submitted jobs to the command line
+        self.jobs: Dict[int, JobDescription] = {}
 
         # A queue of jobs waiting to be executed. Consumed by the daddy thread.
         self.inputQueue = Queue()
@@ -128,8 +130,8 @@ class SingleMachineBatchSystem(BatchSystemSupport):
         # A queue of finished jobs. Produced by the daddy thread.
         self.outputQueue = Queue()
 
-        # A dictionary mapping IDs of currently running jobs to their Info objects
-        self.runningJobs: Dict[str, Info] = {}
+        # A dictionary mapping batch system IDs of currently running jobs to their Info objects
+        self.runningJobs: Dict[int, Info] = {}
 
         # These next two are only used outside debug-worker mode
 
@@ -600,7 +602,7 @@ class SingleMachineBatchSystem(BatchSystemSupport):
 
         log.debug('Child %d for job %s succeeded', pid, jobID)
 
-    def issueBatchJob(self, jobDesc, job_environment: Optional[Dict[str, str]] = None):
+    def issueBatchJob(self, jobDesc: JobDescription, job_environment: Optional[Dict[str, str]] = None) -> int:
         """Adds the command and resources to a queue to be run."""
 
         self._checkOnDaddy()
@@ -635,12 +637,12 @@ class SingleMachineBatchSystem(BatchSystemSupport):
 
         return jobID
 
-    def killBatchJobs(self, jobIDs: Sequence[str]) -> None:
+    def killBatchJobs(self, jobIDs: List[int]) -> None:
         """Kills jobs by ID."""
 
         self._checkOnDaddy()
 
-        log.debug('Killing jobs: {}'.format(jobIDs))
+        log.debug(f'Killing jobs: {jobIDs}')
 
         # Collect the popen handles for the jobs we have to stop
         popens: List[subprocess.Popen] = []
@@ -665,25 +667,22 @@ class SingleMachineBatchSystem(BatchSystemSupport):
                 # Wait for the daddy thread to collect them.
                 time.sleep(0.01)
 
-    def getIssuedBatchJobIDs(self):
+    def getIssuedBatchJobIDs(self) -> List[int]:
         """Just returns all the jobs that have been run, but not yet returned as updated."""
 
         self._checkOnDaddy()
 
         return list(self.jobs.keys())
 
-    def getRunningBatchJobIDs(self):
+    def getRunningBatchJobIDs(self) -> Dict[int, float]:
 
         self._checkOnDaddy()
 
         now = time.time()
         return {jobID: now - info.time for jobID, info in list(self.runningJobs.items())}
 
-    def shutdown(self):
-        """
-        Cleanly terminate and join daddy thread.
-        """
-
+    def shutdown(self) -> None:
+        """Terminate cleanly and join daddy thread."""
         if self.daddyThread is not None:
             # Tell the daddy thread to stop.
             self.shuttingDown.set()
@@ -692,7 +691,7 @@ class SingleMachineBatchSystem(BatchSystemSupport):
 
         BatchSystemSupport.workerCleanup(self.workerCleanupInfo)
 
-    def getUpdatedBatchJob(self, maxWait):
+    def getUpdatedBatchJob(self, maxWait: int) -> Optional[UpdatedBatchJobInfo]:
         """Returns a tuple of a no-longer-running job, the return value of its process, and its runtime, or None."""
 
         self._checkOnDaddy()
@@ -705,9 +704,17 @@ class SingleMachineBatchSystem(BatchSystemSupport):
         log.debug("Ran jobID: %s with exit value: %i", item.jobID, item.exitStatus)
         return item
 
+    @classmethod
+    def add_options(cls, parser: Union[ArgumentParser, _ArgumentGroup]) -> None:
+        parser.add_argument("--scale", dest="scale", default=1,
+                            help="A scaling factor to change the value of all submitted tasks's submitted cores.  "
+                                 "Used in the single_machine batch system. Useful for running workflows on "
+                                 "smaller machines than they were designed for, by setting a value less than 1. "
+                                 "(default: %(default)s)")
+
     @classmethod
     def setOptions(cls, setOption):
-        setOption("scale", default=1)
+        setOption("scale", float, fC(0.0), default=1)
 
 
 class Info:
@@ -736,7 +743,7 @@ class ResourcePool:
     acquired.
     """
     def __init__(self, initial_value, resourceType, timeout=5):
-        super(ResourcePool, self).__init__()
+        super().__init__()
         # We use this condition to signal everyone whenever some resource is released.
         # We use its associated lock to guard value.
         self.condition = Condition()
