@@ -15,24 +15,44 @@ import logging
 import os
 import pickle
 import re
+import signal
 import subprocess
 import sys
 import tempfile
 import time
 import uuid
-
+import warnings
+from argparse import (
+    ArgumentDefaultsHelpFormatter,
+    ArgumentParser,
+    Namespace,
+    _ArgumentGroup,
+)
+from typing import (
+    IO,
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    List,
+    Optional,
+    Tuple,
+    TypeVar,
+    Union,
+)
 from urllib.parse import urlparse
 from argparse import ArgumentDefaultsHelpFormatter, ArgumentParser, _ArgumentGroup
-from typing import Any, Callable, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Tuple, TypeVar, Union
 
 import requests
 
 from toil import logProcessContext, lookupEnvVar
-from toil.fileStores import FileID
 from toil.batchSystems.options import (add_all_batchsystem_options,
                                        set_batchsystem_config_defaults,
                                        set_batchsystem_options)
+from toil.fileStores import FileID
 from toil.lib.aws import zone_to_region
+from toil.lib.compatibility import deprecated
 from toil.lib.conversions import bytes2human, human2bytes
 from toil.lib.retry import retry
 from toil.provisioners import add_provisioner_options, cluster_factory, parse_node_types
@@ -44,15 +64,35 @@ from toil.statsAndLogging import (
 )
 from toil.version import dockerRegistry, dockerTag, version
 
+if TYPE_CHECKING:
+    from toil.batchSystems.abstractBatchSystem import AbstractBatchSystem
+    from toil.jobStores.abstractJobStore import AbstractJobStore
+
 # aim to pack autoscaling jobs within a 30 minute block before provisioning a new node
 defaultTargetTime = 1800
+SYS_MAX_SIZE = 9223372036854775807
+# sys.max_size on 64 bit systems is 9223372036854775807, so that 32-bit systems
+# use the same number
 UUID_LENGTH = 32
 logger = logging.getLogger(__name__)
 
 
 class Config:
     """Class to represent configuration operations for a toil workflow run."""
-    def __init__(self):
+
+    logFile: Optional[str]
+    logRotating: bool
+    workDir: str
+    cleanWorkDir: str
+    maxLocalJobs: int
+    runCwlInternalJobsOnWorkers: bool
+    tes_endpoint: str
+    tes_user: str
+    tes_password: str
+    tes_bearer_token: str
+    jobStore: str
+
+    def __init__(self) -> None:
         # Core options
         self.workflowID: Optional[str] = None
         """This attribute uniquely identifies the job store and therefore the workflow. It is
@@ -62,14 +102,13 @@ class Config:
         self.workflowAttemptNumber = None
         self.jobStore = None
         self.logLevel: str = logging.getLevelName(root_logger.getEffectiveLevel())
-        self.workDir: Optional[str] = None
+        self.workDir = None
         self.noStdOutErr: bool = False
         self.stats: bool = False
 
         # Because the stats option needs the jobStore to persist past the end of the run,
         # the clean default value depends the specified stats option and is determined in setOptions
         self.clean = None
-        self.cleanWorkDir: Optional[bool] = None
         self.clusterStats = None
 
         # Restarting the workflow options
@@ -77,6 +116,11 @@ class Config:
 
         # Batch system options
         set_batchsystem_config_defaults(self)
+        
+        # File store options
+        self.disableCaching: bool = False
+        self.linkImports: bool = True
+        self.moveExports: bool = False
 
         # Autoscaling options
         self.provisioner = None
@@ -96,7 +140,6 @@ class Config:
         self.maxServiceJobs: int = sys.maxsize
         self.deadlockWait: Union[float, int] = 60  # Number of seconds we must be stuck with all services before declaring a deadlock
         self.deadlockCheckInterval: Union[float, int] = 30  # Minimum polling delay for deadlocks
-        self.statePollingWait: Optional[Union[float, int]] = None  # Number of seconds to wait before querying job state
 
         # Resource requirements
         self.defaultMemory: int = 2147483648
@@ -104,19 +147,19 @@ class Config:
         self.defaultDisk: int = 2147483648
         self.readGlobalFileMutableByDefault: bool = False
         self.defaultPreemptable: bool = False
-        self.maxCores: int = sys.maxsize
-        self.maxMemory: int = sys.maxsize
-        self.maxDisk: int = sys.maxsize
+        self.maxCores: int = SYS_MAX_SIZE
+        self.maxMemory: int = SYS_MAX_SIZE
+        self.maxDisk: int = SYS_MAX_SIZE
 
         # Retrying/rescuing jobs
         self.retryCount: int = 1
         self.enableUnlimitedPreemptableRetries: bool = False
         self.doubleMem: bool = False
         self.maxJobDuration: int = sys.maxsize
-        self.rescueJobsFrequency: int = 3600
+        self.rescueJobsFrequency: int = 60
 
         # Misc
-        self.disableCaching: bool = False
+        self.environment: Dict[str, str] = {}
         self.disableChaining: bool = False
         self.disableJobStoreChecksumVerification: bool = False
         self.maxLogFileSize: int = 64000
@@ -127,7 +170,6 @@ class Config:
         self.servicePollingInterval: int = 60
         self.useAsync: bool = True
         self.forceDockerAppliance: bool = False
-        self.runCwlInternalJobsOnWorkers: bool = False
         self.statusWait: int = 3600
         self.disableProgress: bool = False
 
@@ -142,14 +184,56 @@ class Config:
 
     def setOptions(self, options) -> None:
         """Creates a config object from the options object."""
+        OptionType = TypeVar('OptionType')
         def set_option(option_name: str,
-                       parsing_function: Optional[Callable] = None,
-                       check_function: Optional[Callable] = None,
-                       default: Any = None) -> None:
+                       parsing_function: Optional[Callable[[Any], OptionType]] = None,
+                       check_function: Optional[Callable[[OptionType], None]] = None,
+                       default: Optional[OptionType] = None,
+                       env: Optional[List[str]] = None,
+                       old_names: Optional[List[str]] = None) -> None:
+            """
+            Determine the correct value for the given option.
+
+            Priority order is:
+
+            1. options object under option_name
+            2. options object under old_names
+            3. environment variables in env
+            4. provided default value
+
+            Selected option value is run through parsing_funtion if it is set.
+            Then the parsed value is run through check_function to check it for
+            acceptability, which should raise AssertionError if the value is
+            unacceptable.
+
+            If the option gets a non-None value, sets it as an attribute in
+            this Config.
+            """
+
             option_value = getattr(options, option_name, default)
 
-            if option_value is not None:
+            if old_names is not None:
+                for old_name in old_names:
+                    # Try all the old names in case user code is setting them
+                    # in an options object.
+                    if option_value != default:
+                        break
+                    if hasattr(options, old_name):
+                        warnings.warn(f'Using deprecated option field {old_name} to '
+                                      f'provide value for config field {option_name}',
+                                      DeprecationWarning)
+                        option_value = getattr(options, old_name)
+
+            if env is not None:
+                for env_var in env:
+                    # Try all the environment variables
+                    if option_value != default:
+                        break
+                    option_value = os.environ.get(env_var, default)
+
+            if option_value is not None or not hasattr(self, option_name):
                 if parsing_function is not None:
+                    # Parse whatever it is (string, argparse-made list, etc.)
                     option_value = parsing_function(option_value)
                 if check_function is not None:
                     try:
@@ -209,17 +293,11 @@ class Config:
         # Batch system options
         set_option("batchSystem")
         set_batchsystem_options(self.batchSystem, set_option)
-        set_option("disableAutoDeployment")
-        set_option("coalesceStatusCalls")
-        set_option("scale", float, fC(0.0))
-        set_option("parasolCommand")
-        set_option("parasolMaxBatches", int, iC(1))
-        set_option("linkImports")
-        set_option("moveExports")
-        set_option("allocate_mem")
-        set_option("mesosMasterAddress")
-        set_option("kubernetesHostPath")
-        set_option("environment", parseSetEnv)
+
+        # File store options
+        set_option("linkImports", bool, default=True)
+        set_option("moveExports", bool, default=False)
+        set_option("disableCaching", bool, default=False)
 
         # Autoscaling options
         set_option("provisioner")
@@ -255,7 +333,6 @@ class Config:
         set_option("maxPreemptableServiceJobs", int)
         set_option("deadlockWait", int)
         set_option("deadlockCheckInterval", int)
-        set_option("statePollingWait", int)
 
         # Resource requirements
         set_option("defaultMemory", h2b, iC(1))
@@ -275,8 +352,7 @@ class Config:
         set_option("rescueJobsFrequency", int, iC(1))
 
         # Misc
-        set_option("maxLocalJobs", int)
-        set_option("disableCaching")
+        set_option("environment", parseSetEnv)
         set_option("disableChaining")
         set_option("disableJobStoreChecksumVerification")
         set_option("maxLogFileSize", h2b, iC(1))
@@ -284,6 +360,7 @@ class Config:
         set_option("writeLogsGzip")
         set_option("writeLogsFromAllJobs")
         set_option("runCwlInternalJobsOnWorkers")
+        set_option("statusWait", int)
         set_option("disableProgress")
 
         assert not (self.writeLogs and self.writeLogsGzip), \
@@ -327,8 +404,10 @@ JOBSTORE_HELP = ("The location of the job store for the workflow.  "
                  "file:./foo or just file:foo) or /bar (equivalent to file:/bar).")
 
 
-def parser_with_common_options(provisioner_options=False, jobstore_option=True):
-    parser = ArgumentParser(prog='Toil', formatter_class=ArgumentDefaultsHelpFormatter)
+def parser_with_common_options(
+    provisioner_options: bool = False, jobstore_option: bool = True
+) -> ArgumentParser:
+    parser = ArgumentParser(prog="Toil", formatter_class=ArgumentDefaultsHelpFormatter)
 
     if provisioner_options:
         add_provisioner_options(parser)
@@ -409,10 +488,34 @@ def addOptions(parser: ArgumentParser, config: Config = Config()):
         title="Toil options for specifying the batch system.",
         description="Allows the specification of the batch system."
     )
-    batchsystem_options.add_argument("--statePollingWait", dest="statePollingWait", type=int,
-                                     help="Time, in seconds, to wait before doing a scheduler query for job state.  "
-                                          "Return cached results if within the waiting period.")
     add_all_batchsystem_options(batchsystem_options)
+    
+    # File store options
+    file_store_options = parser.add_argument_group(
+        title="Toil options for configuring storage.",
+        description="Allows configuring Toil's data storage."
+    )
+    link_imports = file_store_options.add_mutually_exclusive_group()
+    link_imports_help = ("When using a filesystem based job store, CWL input files are by default symlinked in.  "
+                         "Specifying this option instead copies the files into the job store, which may protect "
+                         "them from being modified externally.  When not specified and as long as caching is enabled, "
+                         "Toil will protect the file automatically by changing the permissions to read-only.")
+    link_imports.add_argument("--linkImports", dest="linkImports", action='store_true', help=link_imports_help)
+    link_imports.add_argument("--noLinkImports", dest="linkImports", action='store_false', help=link_imports_help)
+    link_imports.set_defaults(linkImports=True)
+
+    move_exports = file_store_options.add_mutually_exclusive_group()
+    move_exports_help = ('When using a filesystem based job store, output files are by default moved to the '
+                         'output directory, and a symlink to the moved exported file is created at the initial '
+                         'location.  Specifying this option instead copies the files into the output directory.  '
+                         'Applies to filesystem-based job stores only.')
+    move_exports.add_argument("--moveExports", dest="moveExports", action='store_true', help=move_exports_help)
+    move_exports.add_argument("--noMoveExports", dest="moveExports", action='store_false', help=move_exports_help)
+    move_exports.set_defaults(moveExports=False)
+    file_store_options.add_argument('--disableCaching', dest='disableCaching', action='store_true',
+                                    default=False,
+                                    help='Disables caching in the file store. This flag must be set to use '
+                                         'a batch system that does not support cleanup, such as Parasol.')
 
     # Auto scaling options
     autoscaling_options = parser.add_argument_group(
@@ -594,10 +697,6 @@ def addOptions(parser: ArgumentParser, config: Config = Config()):
         title="Toil miscellaneous options.",
         description="Everything else."
     )
-    misc_options.add_argument('--disableCaching', dest='disableCaching', type='bool', nargs='?', const=True,
-                              default=False,
-                              help='Disables caching in the file store. This flag must be set to use '
-                                   'a batch system that does not support cleanup, such as Parasol.')
     misc_options.add_argument('--disableChaining', dest='disableChaining', action='store_true', default=False,
                               help="Disables chaining of jobs (chaining uses one job's resource allocation "
                                    "for its successor job if possible).")
@@ -629,7 +728,7 @@ def addOptions(parser: ArgumentParser, config: Config = Config()):
                                    "necessarily setting the log level to 'debug'. Ensure that either --writeLogs "
                                    "or --writeLogsGzip is set if enabling this option.")
     misc_options.add_argument("--realTimeLogging", dest="realTimeLogging", action="store_true", default=False,
-                              help="Enable real-time logging from workers to masters")
+                              help="Enable real-time logging from workers to leader")
     misc_options.add_argument("--sseKey", dest="sseKey", default=None,
                               help="Path to file containing 32 character key to be used for server-side encryption on "
                                    "awsJobStore or googleJobStore. SSE will not be used if this flag is not passed.")
@@ -646,6 +745,8 @@ def addOptions(parser: ArgumentParser, config: Config = Config()):
     misc_options.add_argument('--forceDockerAppliance', dest='forceDockerAppliance', action='store_true', default=False,
                               help='Disables sanity checking the existence of the docker image specified by '
                                    'TOIL_APPLIANCE_SELF, which Toil uses to provision mesos for autoscaling.')
+    misc_options.add_argument('--statusWait', dest='statusWait', type=int, default=3600,
+                              help="Seconds to wait between reports of running jobs.")
     misc_options.add_argument('--disableProgress', dest='disableProgress', action='store_true', default=False,
                               help="Disables the progress bar shown when standard error is a terminal.")
 
@@ -674,9 +775,9 @@ def getNodeID() -> str:
     for idSourceFile in ["/var/lib/dbus/machine-id", "/proc/sys/kernel/random/boot_id"]:
         if os.path.exists(idSourceFile):
             try:
-                with open(idSourceFile, "r") as inp:
+                with open(idSourceFile) as inp:
                     nodeID = inp.readline().strip()
-            except EnvironmentError:
+            except OSError:
                 logger.warning(f"Exception when trying to read ID file {idSourceFile}.  "
                                f"Will try next method to get node ID.", exc_info=True)
             else:
@@ -723,14 +824,16 @@ class Toil:
     and its configuration.
     """
 
-    def __init__(self, options):
+    def __init__(self, options: Namespace) -> None:
         """
-        Initialize a Toil object from the given options. Note that this is very light-weight and
-        that the bulk of the work is done when the context is entered.
+        Initialize a Toil object from the given options.
 
-        :param argparse.Namespace options: command line options specified by the user
+        Note that this is very light-weight and that the bulk of the work is
+        done when the context is entered.
+
+        :param options: command line options specified by the user
         """
-        super(Toil, self).__init__()
+        super().__init__()
         self.options = options
         self.config = None
         """
@@ -771,10 +874,14 @@ class Toil:
             config = jobStore.config
             config.setOptions(self.options)
             config.workflowAttemptNumber += 1
-            jobStore.writeConfig()
+            jobStore.write_config()
         self.config = config
         self._jobStore = jobStore
         self._inContextManager = True
+
+        # This will make sure `self.__exit__()` is called when we get a SIGTERM signal.
+        signal.signal(signal.SIGTERM, lambda *_: sys.exit(1))
+
         return self
 
     # noinspection PyUnusedLocal
@@ -784,8 +891,8 @@ class Toil:
         """
         try:
             if (exc_type is not None and self.config.clean == "onError" or
-                            exc_type is None and self.config.clean == "onSuccess" or
-                        self.config.clean == "always"):
+                    exc_type is None and self.config.clean == "onSuccess" or
+                    self.config.clean == "always"):
 
                 try:
                     if self.config.restart and not self._inRestart:
@@ -831,7 +938,7 @@ class Toil:
             # a shared file, where we can find and unpickle it at the end of the workflow.
             # Unpickling the promise will automatically substitute the promise for the actual
             # return value.
-            with self._jobStore.writeSharedFileStream('rootJobReturnValue') as fH:
+            with self._jobStore.write_shared_file_stream('rootJobReturnValue') as fH:
                 rootJob.prepareForPromiseRegistration(self._jobStore)
                 promise = rootJob.rv()
                 pickle.dump(promise, fH, protocol=pickle.HIGHEST_PROTOCOL)
@@ -860,11 +967,11 @@ class Toil:
 
         from toil.job import JobException
         try:
-            self._jobStore.loadRootJob()
+            self._jobStore.load_root_job()
         except JobException:
             logger.warning(
                 'Requested restart but the workflow has already been completed; allowing exports to rerun.')
-            return self._jobStore.getRootJobReturnValue()
+            return self._jobStore.get_root_job_return_value()
 
         self._batchSystem = self.createBatchSystem(self.config)
         self._setupAutoDeployment()
@@ -891,14 +998,13 @@ class Toil:
             self._provisioner.setAutoscaledNodeTypes(self.config.nodeTypes)
 
     @classmethod
-    def getJobStore(cls, locator):
+    def getJobStore(cls, locator: str) -> "AbstractJobStore":
         """
         Create an instance of the concrete job store implementation that matches the given locator.
 
         :param str locator: The location of the job store to be represent by the instance
 
         :return: an instance of a concrete subclass of AbstractJobStore
-        :rtype: toil.jobStores.abstractJobStore.AbstractJobStore
         """
         name, rest = cls.parseLocator(locator)
         if name == 'file':
@@ -914,7 +1020,7 @@ class Toil:
             raise RuntimeError("Unknown job store implementation '%s'" % name)
 
     @staticmethod
-    def parseLocator(locator):
+    def parseLocator(locator: str) -> Tuple[str, str]:
         if locator[0] in '/.' or ':' not in locator:
             return 'file', locator
         else:
@@ -931,13 +1037,13 @@ class Toil:
         return f'{name}:{rest}'
 
     @classmethod
-    def resumeJobStore(cls, locator):
+    def resumeJobStore(cls, locator) -> "AbstractJobStore":
         jobStore = cls.getJobStore(locator)
         jobStore.resume()
         return jobStore
 
     @staticmethod
-    def createBatchSystem(config):
+    def createBatchSystem(config: Config) -> "AbstractBatchSystem":
         """
         Creates an instance of the batch system specified in the given config.
 
@@ -987,7 +1093,7 @@ class Toil:
                         not self.config.disableAutoDeployment):
                     # Note that by saving the ModuleDescriptor, and not the Resource we allow for
                     # redeploying a potentially modified user script on workflow restarts.
-                    with self._jobStore.writeSharedFileStream('userScript') as f:
+                    with self._jobStore.write_shared_file_stream('userScript') as f:
                         pickle.dump(userScript, f, protocol=pickle.HIGHEST_PROTOCOL)
                 else:
                     from toil.batchSystems.singleMachine import \
@@ -1002,7 +1108,7 @@ class Toil:
                 # We could deploy a user script
                 from toil.jobStores.abstractJobStore import NoSuchFileException
                 try:
-                    with self._jobStore.readSharedFileStream('userScript') as f:
+                    with self._jobStore.read_shared_file_stream('userScript') as f:
                         userScript = safeUnpickleFromStream(f)
                 except NoSuchFileException:
                     logger.debug('User script neither set explicitly nor present in the job store.')
@@ -1015,10 +1121,17 @@ class Toil:
             logger.debug('Injecting user script %s into batch system.', userScriptResource)
             self._batchSystem.setUserScript(userScriptResource)
 
+    @deprecated(new_function_name='import_file')
     def importFile(self,
                    srcUrl: str,
                    sharedFileName: Optional[str] = None,
                    symlink: bool = False) -> Optional[Union[FileID, str]]:
+        return self.import_file(srcUrl, sharedFileName, symlink)
+
+    def import_file(self,
+                    src_uri: str,
+                    shared_file_name: Optional[str] = None,
+                    symlink: bool = False) -> Optional[Union[FileID, str]]:
         """
         Imports the file at the given URL into job store.
 
@@ -1026,10 +1139,14 @@ class Toil:
         full description
         """
         self._assertContextManagerUsed()
-        srcUrl = self.normalize_uri(srcUrl, check_existence=True)
-        return self._jobStore.importFile(srcUrl, sharedFileName=sharedFileName, symlink=symlink)
+        src_uri = self.normalize_uri(src_uri, check_existence=True)
+        return self._jobStore.import_file(src_uri, shared_file_name=shared_file_name, symlink=symlink)
 
+    @deprecated(new_function_name='export_file')
     def exportFile(self, jobStoreFileID: Union[FileID, str], dstUrl: str) -> None:
+        return self.export_file(jobStoreFileID, dstUrl)
+
+    def export_file(self, file_id: Union[FileID, str], dst_uri: str) -> None:
         """
         Exports file to destination pointed at by the destination URL.
 
@@ -1037,8 +1154,8 @@ class Toil:
         full description
         """
         self._assertContextManagerUsed()
-        dstUrl = self.normalize_uri(dstUrl)
-        self._jobStore.exportFile(jobStoreFileID, dstUrl)
+        dst_uri = self.normalize_uri(dst_uri)
+        self._jobStore.export_file(file_id, dst_uri)
 
     @staticmethod
     def normalize_uri(uri: str, check_existence: bool = False) -> str:
@@ -1066,7 +1183,7 @@ class Toil:
         """
         Sets the environment variables required by the job store and those passed on command line.
         """
-        for envDict in (self._jobStore.getEnv(), self.config.environment):
+        for envDict in (self._jobStore.get_env(), self.config.environment):
             for k, v in envDict.items():
                 self._batchSystem.setEnv(k, v)
 
@@ -1075,7 +1192,7 @@ class Toil:
         Puts the environment in a globally accessible pickle file.
         """
         # Dump out the environment of this process in the environment pickle file.
-        with self._jobStore.writeSharedFileStream("environment.pickle") as fileHandle:
+        with self._jobStore.write_shared_file_stream("environment.pickle") as fileHandle:
             pickle.dump(dict(os.environ), fileHandle, pickle.HIGHEST_PROTOCOL)
         logger.debug("Written the environment for the jobs to the environment file")
 
@@ -1114,14 +1231,15 @@ class Toil:
         return workDir
 
     @classmethod
-    def getLocalWorkflowDir(cls, workflowID, configWorkDir=None):
+    def getLocalWorkflowDir(
+        cls, workflowID: str, configWorkDir: Optional[str] = None
+    ) -> str:
         """
         Returns a path to the directory where worker directories and the cache will be located
         for this workflow on this machine.
 
-        :param str configWorkDir: Value passed to the program using the --workDir flag
+        :param configWorkDir: Value passed to the program using the --workDir flag
         :return: Path to the local workflow directory on this machine
-        :rtype: str
         """
         # Get the global Toil work directory. This ensures that it exists.
         base = cls.getToilWorkDir(configWorkDir=configWorkDir)
@@ -1159,7 +1277,7 @@ class Toil:
                           rootJob=rootJob,
                           jobCache=self._jobCache).run()
 
-    def _shutdownBatchSystem(self):
+    def _shutdownBatchSystem(self) -> None:
         """
         Shuts down current batch system if it has been created.
         """
@@ -1183,18 +1301,18 @@ class Toil:
         Other methods will rely on always having the most current pid available.
         So far there is no reason to store any old pids.
         """
-        with self._jobStore.writeSharedFileStream('pid.log') as f:
+        with self._jobStore.write_shared_file_stream('pid.log') as f:
             f.write(str(os.getpid()).encode('utf-8'))
 
 
 class ToilRestartException(Exception):
     def __init__(self, message):
-        super(ToilRestartException, self).__init__(message)
+        super().__init__(message)
 
 
 class ToilContextManagerException(Exception):
     def __init__(self):
-        super(ToilContextManagerException, self).__init__(
+        super().__init__(
             'This method cannot be called outside the "with Toil(...)" context manager.')
 
 
@@ -1215,9 +1333,9 @@ class ToilMetrics:
                                 envName='TOIL_DOCKER_REGISTRY',
                                 defaultValue=dockerRegistry)
 
-        self.mtailImage = "%s/toil-mtail:%s" % (registry, dockerTag)
-        self.grafanaImage = "%s/toil-grafana:%s" % (registry, dockerTag)
-        self.prometheusImage = "%s/toil-prometheus:%s" % (registry, dockerTag)
+        self.mtailImage = f"{registry}/toil-mtail:{dockerTag}"
+        self.grafanaImage = f"{registry}/toil-grafana:{dockerTag}"
+        self.prometheusImage = f"{registry}/toil-prometheus:{dockerTag}"
 
         self.startDashboard(clusterName=clusterName, zone=region)
 
@@ -1327,9 +1445,9 @@ class ToilMetrics:
     def logMissingJob(self):
         self.log("missing_job")
 
-    def logClusterSize(self, nodeType, currentSize, desiredSize):
-        self.log("current_size '%s' %i" % (nodeType, currentSize))
-        self.log("desired_size '%s' %i" % (nodeType, desiredSize))
+    def logClusterSize(self, instance_type, currentSize, desiredSize):
+        self.log("current_size '%s' %i" % (instance_type, currentSize))
+        self.log("desired_size '%s' %i" % (instance_type, desiredSize))
 
     def logQueueSize(self, queueSize):
         self.log("queue_size %i" % queueSize)
@@ -1343,7 +1461,7 @@ class ToilMetrics:
     def logCompletedJob(self, jobType):
         self.log("completed_job %s" % jobType)
 
-    def shutdown(self):
+    def shutdown(self) -> None:
         if self.mtailProc:
             self.mtailProc.kill()
         if self.nodeExporterProc:
@@ -1393,7 +1511,7 @@ def parseSetEnv(l):
     return d
 
 
-def iC(minValue, maxValue=sys.maxsize):
+def iC(minValue, maxValue=SYS_MAX_SIZE):
     # Returns function that checks if a given int is in the given half-open interval
     assert isinstance(minValue, int) and isinstance(maxValue, int)
     return lambda x: minValue <= x < maxValue
@@ -1409,7 +1527,7 @@ def fC(minValue, maxValue=None):
         return lambda x: minValue <= x < maxValue
 
 
-def cacheDirName(workflowID):
+def cacheDirName(workflowID: str) -> str:
     """
     :return: Name of the cache directory.
     """
@@ -1463,6 +1581,6 @@ def getFileSystemSize(dirPath: str) -> Tuple[int, int]:
     return freeSpace, diskSize
 
 
-def safeUnpickleFromStream(stream):
+def safeUnpickleFromStream(stream: IO[Any]) -> Any:
     string = stream.read()
     return pickle.loads(string)
