@@ -17,20 +17,40 @@ import tempfile
 from abc import ABC, abstractmethod
 from contextlib import contextmanager
 from threading import Event, Semaphore
-from typing import (List, Dict, Set, Any, BinaryIO, Callable, ContextManager, Generator, Iterator,
-                    Optional, TextIO, Tuple, Union, TYPE_CHECKING, cast)
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    BinaryIO,
+    Callable,
+    ContextManager,
+    Dict,
+    Generator,
+    Iterator,
+    List,
+    Optional,
+    Set,
+    TextIO,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
+
 import dill
 
 from toil.common import cacheDirName
 from toil.fileStores import FileID
-from toil.jobStores.abstractJobStore import AbstractJobStore
-from toil.lib.io import WriteWatchingStream
 from toil.job import Job, JobDescription
+from toil.jobStores.abstractJobStore import AbstractJobStore
+from toil.lib.compatibility import deprecated
+from toil.lib.io import WriteWatchingStream
+
 logger = logging.getLogger(__name__)
 
 if TYPE_CHECKING:
-    from toil.fileStores.nonCachingFileStore import NonCachingFileStore
     from toil.fileStores.cachingFileStore import CachingFileStore
+    from toil.fileStores.nonCachingFileStore import NonCachingFileStore
+
 
 class AbstractFileStore(ABC):
     """
@@ -61,20 +81,25 @@ class AbstractFileStore(ABC):
     _pendingFileWrites: Set[str] = set()
     _terminateEvent = Event()  # Used to signify crashes in threads
 
-    def __init__(self, jobStore: AbstractJobStore, jobDesc: JobDescription, localTempDir: str, waitForPreviousCommit: Callable[[], None]) -> None:
+    def __init__(
+        self,
+        jobStore: AbstractJobStore,
+        jobDesc: JobDescription,
+        localTempDir: str,
+        waitForPreviousCommit: Callable[[], Any],
+    ) -> None:
         """
         Create a new file store object.
 
-        :param toil.jobStores.abstractJobStore.AbstractJobStore jobStore: the job store
-               in use for the current Toil run.
-        :param toil.job.JobDescription jobDesc: the JobDescription object for the currently
+        :param jobStore: the job store in use for the current Toil run.
+        :param jobDesc: the JobDescription object for the currently
                running job.
-        :param str localTempDir: the per-worker local temporary directory, under which
+        :param localTempDir: the per-worker local temporary directory, under which
                per-job directories will be created. Assumed to be inside the
                workflow directory, which is assumed to be inside the work directory.
 
-        :param waitForPreviousCommit: the waitForCommit method of the previous job's file
-               store, when jobs are running in sequence on the same worker. Used to
+        :param waitForPreviousCommit: the waitForCommit method of the previous job's
+               file store, when jobs are running in sequence on the same worker. Used to
                prevent this file store's startCommit and the previous job's
                startCommit methods from running at the same time and racing. If
                they did race, it might be possible for the later job to be fully
@@ -85,7 +110,9 @@ class AbstractFileStore(ABC):
         self.localTempDir: str = os.path.abspath(localTempDir)
         self.workFlowDir = os.path.dirname(self.localTempDir)
         self.workDir: str = os.path.dirname(self.localTempDir)
-        self.jobName: str = self.jobDesc.command.split()[1]
+        self.jobName: str = (
+            self.jobDesc.command.split()[1] if self.jobDesc.command else ""
+        )
         self.waitForPreviousCommit = waitForPreviousCommit
         self.loggingMessages: List[Dict[str, Union[int, str]]] = []
         # Records file IDs of files deleted during the current job. Doesn't get
@@ -102,11 +129,21 @@ class AbstractFileStore(ABC):
         self._accessLog: List[Tuple[str, ...]] = []
 
     @staticmethod
-    def createFileStore(jobStore: AbstractJobStore, jobDesc: JobDescription, localTempDir: str, waitForPreviousCommit: Callable[[], bool], caching: bool) -> Union['NonCachingFileStore', 'CachingFileStore']:
+    def createFileStore(
+        jobStore: AbstractJobStore,
+        jobDesc: JobDescription,
+        localTempDir: str,
+        waitForPreviousCommit: Callable[[], Any],
+        caching: bool,
+    ) -> Union["NonCachingFileStore", "CachingFileStore"]:
+        """Create a concreate FileStore."""
         # Defer these imports until runtime, since these classes depend on us
         from toil.fileStores.cachingFileStore import CachingFileStore
         from toil.fileStores.nonCachingFileStore import NonCachingFileStore
-        fileStoreCls = CachingFileStore if caching else NonCachingFileStore
+
+        fileStoreCls: Union[Type["CachingFileStore"], Type["NonCachingFileStore"]] = (
+            CachingFileStore if caching else NonCachingFileStore
+        )
         return fileStoreCls(jobStore, jobDesc, localTempDir, waitForPreviousCommit)
 
     @staticmethod
@@ -114,25 +151,25 @@ class AbstractFileStore(ABC):
         """
         Carry out any necessary filestore-specific cleanup.
 
-        This is a destructive operation and it is important to ensure that there are no other running
-        processes on the system that are modifying or using the file store for this workflow.
+        This is a destructive operation and it is important to ensure that there
+        are no other running processes on the system that are modifying or using
+        the file store for this workflow.
 
-        This is the intended to be the last call to the file store in a Toil run, called by the
-        batch system cleanup function upon batch system shutdown.
+        This is the intended to be the last call to the file store in a Toil run,
+        called by the batch system cleanup function upon batch system shutdown.
 
         :param workflowDir: The path to the cache directory
         :param workflowID: The workflow ID for this invocation of the workflow
         """
-
         # Defer these imports until runtime, since these classes depend on our file
         from toil.fileStores.cachingFileStore import CachingFileStore
         from toil.fileStores.nonCachingFileStore import NonCachingFileStore
 
         cacheDir = os.path.join(workflowDir, cacheDirName(workflowID))
         if os.path.exists(cacheDir):
-            # The presence of the cacheDir suggests this was a cached run. We don't need the cache lock
-            # for any of this since this is the final cleanup of a job and there should be  no other
-            # conflicting processes using the cache.
+            # The presence of the cacheDir suggests this was a cached run. We don't need
+            # the cache lock for any of this since this is the final cleanup of a job
+            # and there should be  no other conflicting processes using the cache.
             CachingFileStore.shutdown(cacheDir)
         else:
             # This absence of cacheDir suggests otherwise.
@@ -141,15 +178,14 @@ class AbstractFileStore(ABC):
     @contextmanager
     def open(self, job: Job) -> Generator[None, None, None]:
         """
-        The context manager used to conduct tasks prior-to, and after a job has
-        been run. File operations are only permitted inside the context
-        manager.
+        Create the context manager around tasks prior and after a job has been run.
+
+        File operations are only permitted inside the context manager.
 
         Implementations must only yield from within `with super().open(job):`.
 
-        :param toil.job.Job job: The job instance of the toil job to run.
+        :param job: The job instance of the toil job to run.
         """
-
         failed = True
         try:
             yield
@@ -163,12 +199,14 @@ class AbstractFileStore(ABC):
     # Functions related to temp files and directories
     def getLocalTempDir(self) -> str:
         """
-        Get a new local temporary directory in which to write files that persist for the duration of
-        the job.
+        Get a new local temporary directory in which to write files.
 
-        :return: The absolute path to a new local temporary directory. This directory will exist
-                 for the duration of the job only, and is guaranteed to be deleted once the job
-                 terminates, removing all files it contains recursively.
+        The directory will only persist for the duration of the job.
+
+        :return: The absolute path to a new local temporary directory. This directory
+                 will exist for the duration of the job only, and is guaranteed
+                 to be deleted once the job terminates, removing all files it
+                 contains recursively.
         """
         return os.path.abspath(tempfile.mkdtemp(dir=self.localTempDir))
 
@@ -176,10 +214,13 @@ class AbstractFileStore(ABC):
         """
         Get a new local temporary file that will persist for the duration of the job.
 
-        :return: The absolute path to a local temporary file. This file will exist for the
-                 duration of the job only, and is guaranteed to be deleted once the job terminates.
+        :return: The absolute path to a local temporary file. This file will exist
+                 for the duration of the job only, and is guaranteed to be deleted
+                 once the job terminates.
         """
-        handle, tmpFile = tempfile.mkstemp(prefix="tmp", suffix=".tmp", dir=self.localTempDir)
+        handle, tmpFile = tempfile.mkstemp(
+            prefix="tmp", suffix=".tmp", dir=self.localTempDir
+        )
         os.close(handle)
         return os.path.abspath(tmpFile)
 
@@ -189,9 +230,10 @@ class AbstractFileStore(ABC):
 
         :return: Path to valid file
         """
-        # Create, and then delete a temp file. Creating will guarantee you a unique, unused
-        # file name. There is a very, very, very low chance that another job will create the
-        # same file name in the span of this one being deleted and then being used by the user.
+        # Create, and then delete a temp file. Creating will guarantee you a unique,
+        # unused file name. There is a very, very, very low chance that another
+        # job will create the same file name in the span of this one being deleted
+        # and then being used by the user.
         tempFile = self.getLocalTempFile()
         os.remove(tempFile)
         return tempFile
@@ -200,42 +242,49 @@ class AbstractFileStore(ABC):
     @abstractmethod
     def writeGlobalFile(self, localFileName: str, cleanup: bool = False) -> FileID:
         """
-        Takes a file (as a path) and uploads it to the job store. If the file
-        is in a FileStore-managed temporary directory (i.e. from
+        Upload a file (as a path) to the job store.
+
+        If the file is in a FileStore-managed temporary directory (i.e. from
         :func:`toil.fileStores.abstractFileStore.AbstractFileStore.getLocalTempDir`),
         it will become a local copy of the file, eligible for deletion by
         :func:`toil.fileStores.abstractFileStore.AbstractFileStore.deleteLocalFile`.
 
-        If an executable file on the local filesystem is uploaded, its executability will
-        be preserved when it is downloaded again.
+        If an executable file on the local filesystem is uploaded, its executability
+        will be preserved when it is downloaded again.
 
         :param localFileName: The path to the local file to upload. The
                last path component (basename of the file) will remain
                associated with the file in the file store, if supported by the
                backing JobStore, so that the file can be searched for by name
                or name glob.
-        :param cleanup: if True then the copy of the global file will be deleted once the
-               job and all its successors have completed running.  If not the global file must be
-               deleted manually.
+        :param cleanup: if True then the copy of the global file will be deleted once
+               the job and all its successors have completed running.  If not the global
+               file must be deleted manually.
 
         :return: an ID that can be used to retrieve the file.
         """
         raise NotImplementedError()
 
     @contextmanager
-    def writeGlobalFileStream(self, cleanup: bool = False, basename: Optional[str] = None, encoding: Optional[str] = None,
-                                errors: Optional[str] = None) -> Iterator[Tuple[Union[BinaryIO, TextIO], FileID]]:
+    def writeGlobalFileStream(
+        self,
+        cleanup: bool = False,
+        basename: Optional[str] = None,
+        encoding: Optional[str] = None,
+        errors: Optional[str] = None,
+    ) -> Iterator[Tuple[WriteWatchingStream, FileID]]:
         """
         Similar to writeGlobalFile, but allows the writing of a stream to the job store.
         The yielded file handle does not need to and should not be closed explicitly.
 
-        :param encoding: The name of the encoding used to decode the file. Encodings are the same as
-                for decode(). Defaults to None which represents binary mode.
+        :param encoding: The name of the encoding used to decode the file. Encodings
+            are the same as for decode(). Defaults to None which represents binary mode.
 
-        :param errors: Specifies how encoding errors are to be handled. Errors
-                are the same as for open(). Defaults to 'strict' when an encoding is specified.
+        :param errors: Specifies how encoding errors are to be handled. Errors are the
+            same as for open(). Defaults to 'strict' when an encoding is specified.
 
-        :param cleanup: is as in :func:`toil.fileStores.abstractFileStore.AbstractFileStore.writeGlobalFile`.
+        :param cleanup: is as in
+            :func:`toil.fileStores.abstractFileStore.AbstractFileStore.writeGlobalFile`.
 
         :param basename: If supported by the backing JobStore, use the given
                file basename so that when searching the job store with a query
@@ -245,10 +294,9 @@ class AbstractFileStore(ABC):
                   1) a file handle which can be written to and
                   2) the toil.fileStores.FileID of the resulting file in the job store.
         """
-        
-        with self.jobStore.writeFileStream(self.jobDesc.jobStoreID, cleanup, basename,
-                encoding, errors) as (backingStream, fileStoreID):
-          
+        with self.jobStore.write_file_stream(
+            str(self.jobDesc.jobStoreID), cleanup, basename, encoding, errors
+        ) as (backingStream, fileStoreID):
             # We have a string version of the file ID, and the backing stream.
             # We need to yield a stream the caller can write to, and a FileID
             # that accurately reflects the size of the data written to the
@@ -270,10 +318,10 @@ class AbstractFileStore(ABC):
 
     def _dumpAccessLogs(self) -> None:
         """
-        When something goes wrong, log a report of the files that were accessed
-        while the file store was open.
-        """
+        When something goes wrong, log a report.
 
+        Includes the files that were accessed while the file store was open.
+        """
         if len(self._accessLog) > 0:
             logger.warning('Failed job accessed files:')
 
@@ -286,31 +334,42 @@ class AbstractFileStore(ABC):
                     # Otherwise dump without the name
                     logger.warning('Streamed file \'%s\'', *item)
 
-    def logAccess(self, fileStoreID: Union[FileID, str], destination: Union[str, None] = None) -> None:
+    def logAccess(
+        self, fileStoreID: Union[FileID, str], destination: Union[str, None] = None
+    ) -> None:
         """
-        Record that the given file was read by the job, to be announced if the
-        job fails. If destination is not None, it gives the path that the file
+        Record that the given file was read by the job.
+
+        (to be announced if the job fails)
+
+        If destination is not None, it gives the path that the file
         was downloaded to. Otherwise, assumes that the file was streamed.
 
         Must be called by :meth:`readGlobalFile` and :meth:`readGlobalFileStream`
         implementations.
         """
-
         if destination is not None:
             self._accessLog.append((fileStoreID, destination))
         else:
             self._accessLog.append((fileStoreID,))
 
     @abstractmethod
-    def readGlobalFile(self, fileStoreID: str, userPath: Optional[str] = None, cache: bool = True, mutable: bool = False,
-                        symlink: bool = False) -> str:
+    def readGlobalFile(
+        self,
+        fileStoreID: str,
+        userPath: Optional[str] = None,
+        cache: bool = True,
+        mutable: bool = False,
+        symlink: bool = False,
+    ) -> str:
         """
-        Makes the file associated with fileStoreID available locally. If mutable is True,
-        then a copy of the file will be created locally so that the original is not modified
-        and does not change the file for other jobs. If mutable is False, then a link can
-        be created to the file, saving disk resources. The file that is downloaded will be
-        executable if and only if it was originally uploaded from an executable file on the
-        local filesystem.
+        Make the file associated with fileStoreID available locally.
+
+        If mutable is True, then a copy of the file will be created locally so
+        that the original is not modified and does not change the file for other
+        jobs. If mutable is False, then a link can be created to the file, saving
+        disk resources. The file that is downloaded will be executable if and only
+        if it was originally uploaded from an executable file on the local filesystem.
 
         If a user path is specified, it is used as the destination. If a user path isn't
         specified, the file is stored in the local temp directory with an encoded name.
@@ -320,27 +379,37 @@ class AbstractFileStore(ABC):
 
         Implementations must call :meth:`logAccess` to report the download.
 
-        :param toil.fileStores.FileID or str fileStoreID: job store id for the file
-        :param string userPath: a path to the name of file to which the global file will be copied
-               or hard-linked (see below).
-        :param cache: Described in :func:`toil.fileStores.CachingFileStore.readGlobalFile`
-        :param mutable: Described in :func:`toil.fileStores.CachingFileStore.readGlobalFile`
+        :param fileStoreID: job store id for the file
+        :param userPath: a path to the name of file to which the global file will
+               be copied or hard-linked (see below).
+        :param cache: Described in
+                      :func:`toil.fileStores.CachingFileStore.readGlobalFile`
+        :param mutable: Described in
+                        :func:`toil.fileStores.CachingFileStore.readGlobalFile`
 
-        :return: An absolute path to a local, temporary copy of the file keyed by fileStoreID.
+        :return: An absolute path to a local, temporary copy of the file keyed
+                 by fileStoreID.
         """
         raise NotImplementedError()
 
     @abstractmethod
-    def readGlobalFileStream(self, fileStoreID: str, encoding: Optional[str] = None, errors: Optional[str] = None) -> ContextManager[Union[BinaryIO, TextIO]]:
+    def readGlobalFileStream(
+        self,
+        fileStoreID: str,
+        encoding: Optional[str] = None,
+        errors: Optional[str] = None,
+    ) -> ContextManager[Union[BinaryIO, TextIO]]:
         """
-        Similar to readGlobalFile, but allows a stream to be read from the job store. The yielded
-        file handle does not need to and should not be closed explicitly.
+        Read a stream from the job store; similar to readGlobalFile.
 
-        :param str encoding: the name of the encoding used to decode the file. Encodings are the same as
-                for decode(). Defaults to None which represents binary mode.
+        The yielded file handle does not need to and should not be closed explicitly.
 
-        :param str errors: an optional string that specifies how encoding errors are to be handled. Errors
-                are the same as for open(). Defaults to 'strict' when an encoding is specified.
+        :param encoding: the name of the encoding used to decode the file. Encodings
+            are the same as for decode(). Defaults to None which represents binary mode.
+
+        :param errors: an optional string that specifies how encoding errors are
+            to be handled. Errors are the same as for open(). Defaults to 'strict'
+            when an encoding is specified.
 
         Implementations must call :meth:`logAccess` to report the download.
 
@@ -364,21 +433,21 @@ class AbstractFileStore(ABC):
 
         :return: File's size in bytes, as stored in the job store
         """
-
         # First try and see if the size is still attached
         size = getattr(fileStoreID, 'size', None)
 
         if size is None:
             # It fell off
-            # Someone is mixing FileStore and JobStore file APIs, or serializing FileIDs as strings.
-            size = self.jobStore.getFileSize(fileStoreID)
+            # Someone is mixing FileStore and JobStore file APIs,
+            # or serializing FileIDs as strings.
+            size = self.jobStore.get_file_size(fileStoreID)
 
         return cast(int, size)
 
     @abstractmethod
     def deleteLocalFile(self, fileStoreID: Union[FileID, str]) -> None:
         """
-        Deletes local copies of files associated with the provided job store ID.
+        Delete local copies of files associated with the provided job store ID.
 
         Raises an OSError with an errno of errno.ENOENT if no such local copies
         exist. Thus, cannot be called multiple times in succession.
@@ -396,30 +465,46 @@ class AbstractFileStore(ABC):
     @abstractmethod
     def deleteGlobalFile(self, fileStoreID: Union[FileID, str]) -> None:
         """
-        Deletes local files with the provided job store ID and then permanently deletes them from
-        the job store. To ensure that the job can be restarted if necessary, the delete will not
+        Delete local files and then permanently deletes them from the job store.
+
+        To ensure that the job can be restarted if necessary, the delete will not
         happen until after the job's run method has completed.
 
         :param fileStoreID: the File Store ID of the file to be deleted.
         """
         raise NotImplementedError()
 
-    # Functions used to read and write files directly between a source url and the job store.
-    def importFile(self, srcUrl: str, sharedFileName: Optional[str] = None) -> Optional[FileID]:
-        return self.jobStore.importFile(srcUrl, sharedFileName=sharedFileName)
+    # Functions used to read and write files directly between a source url
+    # and the job store.
+    @deprecated(new_function_name="import_file")
+    def importFile(
+        self, srcUrl: str, sharedFileName: Optional[str] = None
+    ) -> Optional[FileID]:
+        return self.import_file(srcUrl, sharedFileName)
 
+    def import_file(
+        self, src_uri: str, shared_file_name: Optional[str] = None
+    ) -> Optional[FileID]:
+        return self.jobStore.import_file(src_uri, shared_file_name=shared_file_name)
+
+    @deprecated(new_function_name='export_file')
     def exportFile(self, jobStoreFileID: FileID, dstUrl: str) -> None:
+        return self.export_file(jobStoreFileID, dstUrl)
+
+    def export_file(self, file_id: FileID, dst_uri: str) -> None:
         raise NotImplementedError()
 
     # A utility method for accessing filenames
     def _resolveAbsoluteLocalPath(self, filePath: str) -> str:
         """
-        Return the absolute path to filePath.  This is a wrapper for os.path.abspath because mac OS
-        symlinks /tmp and /var (the most common places for a default tempdir) to /private/tmp and
-        /private/var respectively.
+        Return the absolute path to filePath.
 
-        :param filePath: The absolute or relative path to the file. If relative, it must be
-               relative to the local temp working dir
+        This is a wrapper for os.path.abspath because mac OS
+        symlinks /tmp and /var (the most common places for a default tempdir) to
+        /private/tmp and /private/var respectively.
+
+        :param filePath: The absolute or relative path to the file. If relative,
+            it must be relative to the local temp working dir
 
         :return: Absolute path to key
         """
@@ -428,10 +513,9 @@ class AbstractFileStore(ABC):
         else:
             return os.path.join(self.localTempDir, filePath)
 
-    class _StateFile(object):
-        """
-        Utility class to read and write dill-ed state dictionaries from/to a file into a namespace.
-        """
+    class _StateFile:
+        """Read and write dill-ed state dictionaries from/to a file into a namespace."""
+
         def __init__(self, stateDict: Dict[str, Any]):
             assert isinstance(stateDict, dict)
             self.__dict__.update(stateDict)
@@ -449,9 +533,9 @@ class AbstractFileStore(ABC):
             raise NotImplementedError()
 
         @classmethod
-        def _load(cls, fileName: str) -> Any: 
+        def _load(cls, fileName: str) -> Any:
             """
-            Load the state of the cache from the state file
+            Load the state of the cache from the state file.
 
             :param fileName: Path to the cache state file.
 
@@ -466,15 +550,15 @@ class AbstractFileStore(ABC):
 
         def write(self, fileName: str) -> None:
             """
-            Write the current state into a temporary file then atomically rename it to the main
-            state file.
+            Write the current state to the main state file.
 
             :param fileName: Path to the state file.
             """
             with open(fileName + '.tmp', 'wb') as fH:
                 # Based on answer by user "Mark" at:
                 # http://stackoverflow.com/questions/2709800/how-to-pickle-yourself
-                # We can't pickle nested classes. So we have to pickle the variables of the class
+                # We can't pickle nested classes. So we have to pickle the variables
+                # of the class.
                 # If we ever change this, we need to ensure it doesn't break FileID
                 dill.dump(self.__dict__, fH)
             os.rename(fileName + '.tmp', fileName)
@@ -508,9 +592,10 @@ class AbstractFileStore(ABC):
     @abstractmethod
     def waitForCommit(self) -> bool:
         """
-        Blocks while startCommit is running. This function is called by this job's
-        successor to ensure that it does not begin modifying the job store until after this job has
-        finished doing so.
+        Blocks while startCommit is running.
+
+        This function is called by this job's successor to ensure that it does
+        not begin modifying the job store until after this job has finished doing so.
 
         Might be called when startCommit is never called on a particular
         instance, in which case it does not block.
@@ -527,8 +612,8 @@ class AbstractFileStore(ABC):
 
         This is intended to be called on batch system shutdown.
 
-        :param dir_: The implementation-specific directory containing the required information for
-               shutting down the file store and removing all its state and all job local temp
-               directories from the node.
+        :param dir_: The implementation-specific directory containing the required
+            information for shutting down the file store and removing all its state
+            and all job local temp directories from the node.
         """
         raise NotImplementedError()
