@@ -17,24 +17,44 @@ import logging
 import os
 from collections import defaultdict
 from contextlib import contextmanager
-from typing import DefaultDict, List, Dict, BinaryIO, Callable, Iterator, Optional, Generator, TextIO, Union, cast
+from typing import (
+    Any,
+    BinaryIO,
+    Callable,
+    DefaultDict,
+    Dict,
+    Generator,
+    Iterator,
+    List,
+    Optional,
+    TextIO,
+    Union,
+    cast,
+)
 
 import dill
 
 from toil.common import getDirSizeRecursively, getFileSystemSize
 from toil.fileStores import FileID
 from toil.fileStores.abstractFileStore import AbstractFileStore
-from toil.jobStores.abstractJobStore import AbstractJobStore
-from toil.lib.conversions import bytes2human
-from toil.lib.io import robust_rmtree, make_public_dir
-from toil.lib.threading import get_process_name, process_name_exists
 from toil.job import Job, JobDescription
+from toil.jobStores.abstractJobStore import AbstractJobStore
+from toil.lib.compatibility import deprecated
+from toil.lib.conversions import bytes2human
+from toil.lib.io import make_public_dir, robust_rmtree
+from toil.lib.threading import get_process_name, process_name_exists
 
 logger: logging.Logger = logging.getLogger(__name__)
 
 
 class NonCachingFileStore(AbstractFileStore):
-    def __init__(self, jobStore: AbstractJobStore, jobDesc: JobDescription, localTempDir: str, waitForPreviousCommit: Callable[[], None]) -> None:
+    def __init__(
+        self,
+        jobStore: AbstractJobStore,
+        jobDesc: JobDescription,
+        localTempDir: str,
+        waitForPreviousCommit: Callable[[], Any],
+    ) -> None:
         super().__init__(jobStore, jobDesc, localTempDir, waitForPreviousCommit)
         # This will be defined in the `open` method.
         self.jobStateFile: Optional[str] = None
@@ -71,8 +91,8 @@ class NonCachingFileStore(AbstractFileStore):
 
     def writeGlobalFile(self, localFileName: str, cleanup: bool=False) -> FileID:
         absLocalFileName = self._resolveAbsoluteLocalPath(localFileName)
-        creatorID = self.jobDesc.jobStoreID
-        fileStoreID = self.jobStore.writeFile(absLocalFileName, creatorID, cleanup)
+        creatorID = str(self.jobDesc.jobStoreID)
+        fileStoreID = self.jobStore.write_file(absLocalFileName, creatorID, cleanup)
         if absLocalFileName.startswith(self.localTempDir):
             # Only files in the appropriate directory should become local files
             # we can delete with deleteLocalFile
@@ -88,19 +108,23 @@ class NonCachingFileStore(AbstractFileStore):
         else:
             localFilePath = self.getLocalTempFileName()
 
-        self.jobStore.readFile(fileStoreID, localFilePath, symlink=symlink)
+        self.jobStore.read_file(fileStoreID, localFilePath, symlink=symlink)
         self.localFileMap[fileStoreID].append(localFilePath)
         self.logAccess(fileStoreID, localFilePath)
         return localFilePath
 
     @contextmanager
     def readGlobalFileStream(self, fileStoreID: str, encoding: Optional[str] = None, errors: Optional[str] = None) -> Iterator[Union[BinaryIO, TextIO]]:
-        with self.jobStore.readFileStream(fileStoreID, encoding=encoding, errors=errors) as f:
+        with self.jobStore.read_file_stream(fileStoreID, encoding=encoding, errors=errors) as f:
             self.logAccess(fileStoreID)
             yield f
 
+    @deprecated(new_function_name='export_file')
     def exportFile(self, jobStoreFileID: FileID, dstUrl: str) -> None:
-        self.jobStore.exportFile(jobStoreFileID, dstUrl)
+        return self.export_file(jobStoreFileID, dstUrl)
+
+    def export_file(self, file_id: FileID, dst_uri: str) -> None:
+        self.jobStore.export_file(file_id, dst_uri)
 
     def deleteLocalFile(self, fileStoreID: str) -> None:
         try:
@@ -140,16 +164,16 @@ class NonCachingFileStore(AbstractFileStore):
             # the job wrapper is completed.
             self.jobDesc.filesToDelete = list(self.filesToDelete)
             # Complete the job
-            self.jobStore.update(self.jobDesc)
+            self.jobStore.update_job(self.jobDesc)
             # Delete any remnant jobs
-            list(map(self.jobStore.delete, self.jobsToDelete))
+            list(map(self.jobStore.delete_job, self.jobsToDelete))
             # Delete any remnant files
-            list(map(self.jobStore.deleteFile, self.filesToDelete))
+            list(map(self.jobStore.delete_file, self.filesToDelete))
             # Remove the files to delete list, having successfully removed the files
             if len(self.filesToDelete) > 0:
                 self.jobDesc.filesToDelete = []
                 # Update, removing emptying files to delete
-                self.jobStore.update(self.jobDesc)
+                self.jobStore.update_job(self.jobDesc)
         except:
             self._terminateEvent.set()
             raise
@@ -220,7 +244,7 @@ class NonCachingFileStore(AbstractFileStore):
         # We require that the job state files aren't in any of those directories.
         for root, dirs, files in os.walk(workflowDir.encode('utf-8')):
             for filename in files:
-                if filename == '.jobState'.encode('utf-8'):
+                if filename == b'.jobState':
                     jobStateFiles.append(os.path.join(root, filename).decode('utf-8'))
         for fname in jobStateFiles:
             try:
