@@ -11,10 +11,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-import os
 import hashlib
 import itertools
 import logging
+import os
 import pickle
 import re
 import reprlib
@@ -26,44 +26,45 @@ import urllib.request
 import uuid
 from contextlib import contextmanager
 from io import BytesIO
-
-import boto.sdb
-import boto.s3.connection
 from typing import Optional
+
+import boto.s3.connection
+import boto.sdb
 from boto.exception import SDBResponseError
 from botocore.exceptions import ClientError
 
 import toil.lib.encryption as encryption
 from toil.fileStores import FileID
-from toil.jobStores.abstractJobStore import (AbstractJobStore,
-                                             ConcurrentFileModificationException,
-                                             JobStoreExistsException,
-                                             NoSuchFileException,
-                                             NoSuchJobException,
-                                             NoSuchJobStoreException)
-from toil.jobStores.aws.utils import (SDBHelper,
-                                      bucket_location_to_region,
-                                      uploadFromPath,
-                                      uploadFile,
-                                      copyKeyMultipart,
-                                      fileSizeAndTime,
-                                      monkeyPatchSdbConnection,
-                                      no_such_sdb_domain,
-                                      region_to_bucket_location,
-                                      retry_s3,
-                                      retry_sdb,
-                                      retryable_s3_errors,
-                                      sdb_unavailable)
-from toil.jobStores.utils import (ReadablePipe,
-                                  ReadableTransformingPipe,
-                                  WritablePipe)
+from toil.jobStores.abstractJobStore import (
+    AbstractJobStore,
+    ConcurrentFileModificationException,
+    JobStoreExistsException,
+    NoSuchFileException,
+    NoSuchJobException,
+    NoSuchJobStoreException,
+)
+from toil.jobStores.aws.utils import (
+    SDBHelper,
+    bucket_location_to_region,
+    copyKeyMultipart,
+    fileSizeAndTime,
+    monkeyPatchSdbConnection,
+    no_such_sdb_domain,
+    retry_s3,
+    retry_sdb,
+    retryable_s3_errors,
+    sdb_unavailable,
+    uploadFile,
+    uploadFromPath,
+)
+from toil.jobStores.utils import ReadablePipe, ReadableTransformingPipe, WritablePipe
 from toil.lib.aws.utils import create_s3_bucket
 from toil.lib.compatibility import compat_bytes
 from toil.lib.ec2 import establish_boto3_session
 from toil.lib.ec2nodes import EC2Regions
 from toil.lib.exceptions import panic
-from toil.lib.memoize import strict_bool
 from toil.lib.io import AtomicFileCreate
+from toil.lib.memoize import strict_bool
 from toil.lib.objects import InnerClass
 from toil.lib.retry import retry
 
@@ -112,7 +113,7 @@ class AWSJobStore(AbstractJobStore):
                upload and copy, must be >= 5 MiB but large enough to not exceed 10k parts for the
                whole file
         """
-        super(AWSJobStore, self).__init__(locator)
+        super().__init__(locator)
         region, namePrefix = locator.split(':')
         regions = EC2Regions.keys()
         if region not in regions:
@@ -151,7 +152,7 @@ class AWSJobStore(AbstractJobStore):
             with panic(logger):
                 self.destroy()
         else:
-            super(AWSJobStore, self).initialize(config)
+            super().initialize(config)
             # Only register after job store has been full initialized
             self._registered = True
 
@@ -163,7 +164,7 @@ class AWSJobStore(AbstractJobStore):
         if not self._registered:
             raise NoSuchJobStoreException(self.locator)
         self._bind(create=False)
-        super(AWSJobStore, self).resume()
+        super().resume()
 
     def _bind(self, create=False, block=True, check_versioning_consistency=True):
         def qualify(name):
@@ -269,11 +270,11 @@ class AWSJobStore(AbstractJobStore):
     def _awsJobFromItem(self, item):
         self._checkItem(item)
         if item.get("overlargeID", None):
-            assert self.fileExists(item["overlargeID"])
+            assert self.file_exists(item["overlargeID"])
             # This is an overlarge job, download the actual attributes
             # from the file store
             logger.debug("Loading overlarge job from S3.")
-            with self.readFileStream(item["overlargeID"]) as fh:
+            with self.read_file_stream(item["overlargeID"]) as fh:
                 binary = fh.read()
         else:
             binary, _ = SDBHelper.attributesToBinary(item)
@@ -287,7 +288,7 @@ class AWSJobStore(AbstractJobStore):
         binary = pickle.dumps(job, protocol=pickle.HIGHEST_PROTOCOL)
         if len(binary) > SDBHelper.maxBinarySize(extraReservedChunks=1):
             # Store as an overlarge job in S3
-            with self.writeFileStream() as (writable, fileID):
+            with self.write_file_stream() as (writable, fileID):
                 writable.write(binary)
             item = SDBHelper.binaryToAttributes(None)
             item["overlargeID"] = fileID
@@ -314,24 +315,24 @@ class AWSJobStore(AbstractJobStore):
                     assert self.jobsDomain.batch_put_attributes(items)
         self._batchedUpdates = None
 
-    def assignID(self, jobDescription):
-        jobStoreID = self._newJobID()
+    def assign_job_id(self, job_description):
+        jobStoreID = self._new_job_id()
         logger.debug("Assigning ID to job %s for '%s'",
-                     jobStoreID, '<no command>' if jobDescription.command is None else jobDescription.command)
-        jobDescription.jobStoreID = jobStoreID
+                     jobStoreID, '<no command>' if job_description.command is None else job_description.command)
+        job_description.jobStoreID = jobStoreID
 
-    def create(self, jobDescription):
+    def create_job(self, job_description):
         if hasattr(self, "_batchedUpdates") and self._batchedUpdates is not None:
-            self._batchedUpdates.append(jobDescription)
+            self._batchedUpdates.append(job_description)
         else:
-            self.update(jobDescription)
-        return jobDescription
+            self.update_job(job_description)
+        return job_description
 
-    def exists(self, jobStoreID):
+    def job_exists(self, job_id):
         for attempt in retry_sdb():
             with attempt:
                 return bool(self.jobsDomain.get_attributes(
-                    item_name=compat_bytes(jobStoreID),
+                    item_name=compat_bytes(job_id),
                     attribute_name=[SDBHelper.presenceIndicator()],
                     consistent_read=True))
 
@@ -346,58 +347,57 @@ class AWSJobStore(AbstractJobStore):
         for jobItem in result:
             yield self._awsJobFromItem(jobItem)
 
-    def load(self, jobStoreID):
+    def load_job(self, job_id):
         item = None
         for attempt in retry_sdb():
             with attempt:
-                item = self.jobsDomain.get_attributes(compat_bytes(jobStoreID), consistent_read=True)
+                item = self.jobsDomain.get_attributes(compat_bytes(job_id), consistent_read=True)
         if not item:
-            raise NoSuchJobException(jobStoreID)
+            raise NoSuchJobException(job_id)
         job = self._awsJobFromItem(item)
         if job is None:
-            raise NoSuchJobException(jobStoreID)
-        logger.debug("Loaded job %s", jobStoreID)
+            raise NoSuchJobException(job_id)
+        logger.debug("Loaded job %s", job_id)
         return job
 
-    def update(self, jobDescription):
-        logger.debug("Updating job %s", jobDescription.jobStoreID)
-        jobDescription.pre_update_hook()
-        item = self._awsJobToItem(jobDescription)
+    def update_job(self, job_description):
+        logger.debug("Updating job %s", job_description.jobStoreID)
+        job_description.pre_update_hook()
+        item = self._awsJobToItem(job_description)
         for attempt in retry_sdb():
             with attempt:
-                assert self.jobsDomain.put_attributes(compat_bytes(jobDescription.jobStoreID), item)
+                assert self.jobsDomain.put_attributes(compat_bytes(job_description.jobStoreID), item)
 
     itemsPerBatchDelete = 25
 
-    def delete(self, jobStoreID):
+    def delete_job(self, job_id):
         # remove job and replace with jobStoreId.
-        logger.debug("Deleting job %s", jobStoreID)
+        logger.debug("Deleting job %s", job_id)
 
         # If the job is overlarge, delete its file from the filestore
         item = None
         for attempt in retry_sdb():
             with attempt:
-                item = self.jobsDomain.get_attributes(compat_bytes(jobStoreID), consistent_read=True)
+                item = self.jobsDomain.get_attributes(compat_bytes(job_id), consistent_read=True)
         # If the overlargeID has fallen off, maybe we partially deleted the
         # attributes of the item? Or raced on it? Or hit SimpleDB being merely
         # eventually consistent? We should still be able to get rid of it.
         self._checkItem(item, enforce = False)
         if item.get("overlargeID", None):
             logger.debug("Deleting job from filestore")
-            self.deleteFile(item["overlargeID"])
+            self.delete_file(item["overlargeID"])
         for attempt in retry_sdb():
             with attempt:
-                self.jobsDomain.delete_attributes(item_name=compat_bytes(jobStoreID))
+                self.jobsDomain.delete_attributes(item_name=compat_bytes(job_id))
         items = None
         for attempt in retry_sdb():
             with attempt:
                 items = list(self.filesDomain.select(
                     consistent_read=True,
-                    query="select version from `%s` where ownerID='%s'" % (
-                        self.filesDomain.name, jobStoreID)))
+                    query="select version from `{}` where ownerID='{}'".format(self.filesDomain.name, job_id)))
         assert items is not None
         if items:
-            logger.debug("Deleting %d file(s) associated with job %s", len(items), jobStoreID)
+            logger.debug("Deleting %d file(s) associated with job %s", len(items), job_id)
             n = self.itemsPerBatchDelete
             batches = [items[i:i + n] for i in range(0, len(items), n)]
             for batch in batches:
@@ -417,7 +417,7 @@ class AWSJobStore(AbstractJobStore):
                             self.s3_client.delete_object(Bucket=self.filesBucket.name,
                                                          Key=compat_bytes(item.name))
 
-    def getEmptyFileStoreID(self, jobStoreID=None, cleanup=False, basename=None):
+    def get_empty_file_store_id(self, jobStoreID=None, cleanup=False, basename=None):
         info = self.FileInfo.create(jobStoreID if cleanup else None)
         with info.uploadStream() as _:
             # Empty
@@ -426,40 +426,39 @@ class AWSJobStore(AbstractJobStore):
         logger.debug("Created %r.", info)
         return info.fileID
 
-    def _importFile(self, otherCls, url, sharedFileName=None, hardlink=False, symlink=False):
+    def _import_file(self, otherCls, uri, shared_file_name=None, hardlink=False, symlink=False):
         if issubclass(otherCls, AWSJobStore):
-            srcObj = self._getObjectForUrl(url, existing=True)
+            srcObj = self._get_object_for_url(uri, existing=True)
             size = srcObj.content_length
-            if sharedFileName is None:
+            if shared_file_name is None:
                 info = self.FileInfo.create(srcObj.key)
             else:
-                self._requireValidSharedFileName(sharedFileName)
-                jobStoreFileID = self._sharedFileID(sharedFileName)
+                self._requireValidSharedFileName(shared_file_name)
+                jobStoreFileID = self._shared_file_id(shared_file_name)
                 info = self.FileInfo.loadOrCreate(jobStoreFileID=jobStoreFileID,
                                                   ownerID=str(self.sharedFileOwnerID),
                                                   encrypted=None)
             info.copyFrom(srcObj)
             info.save()
-            return FileID(info.fileID, size) if sharedFileName is None else None
+            return FileID(info.fileID, size) if shared_file_name is None else None
         else:
-            return super(AWSJobStore, self)._importFile(otherCls, url,
-                                                        sharedFileName=sharedFileName)
+            return super()._import_file(otherCls, uri, shared_file_name=shared_file_name)
 
-    def _exportFile(self, otherCls, jobStoreFileID, url):
+    def _export_file(self, otherCls, file_id, uri):
         if issubclass(otherCls, AWSJobStore):
-            dstObj = self._getObjectForUrl(url)
-            info = self.FileInfo.loadOrFail(jobStoreFileID)
+            dstObj = self._get_object_for_url(uri)
+            info = self.FileInfo.loadOrFail(file_id)
             info.copyTo(dstObj)
         else:
-            super(AWSJobStore, self)._defaultExportFile(otherCls, jobStoreFileID, url)
+            super()._default_export_file(otherCls, file_id, uri)
 
     @classmethod
-    def getSize(cls, url):
-        return cls._getObjectForUrl(url, existing=True).content_length
+    def get_size(cls, url):
+        return cls._get_object_for_url(url, existing=True).content_length
 
     @classmethod
-    def _readFromUrl(cls, url, writable):
-        srcObj = cls._getObjectForUrl(url, existing=True)
+    def _read_from_url(cls, url, writable):
+        srcObj = cls._get_object_for_url(url, existing=True)
         srcObj.download_fileobj(writable)
         return (
             srcObj.content_length,
@@ -467,8 +466,8 @@ class AWSJobStore(AbstractJobStore):
         )
 
     @classmethod
-    def _writeToUrl(cls, readable, url, executable=False):
-        dstObj = cls._getObjectForUrl(url)
+    def _write_to_url(cls, readable, url, executable=False):
+        dstObj = cls._get_object_for_url(url)
 
         logger.debug("Uploading %s", dstObj.key)
         # uploadFile takes care of using multipart upload if the file is larger than partSize (default to 5MB)
@@ -479,7 +478,7 @@ class AWSJobStore(AbstractJobStore):
                    partSize=5 * 1000 * 1000)
 
     @staticmethod
-    def _getObjectForUrl(url, existing: Optional[bool] = None):
+    def _get_object_for_url(url, existing: Optional[bool] = None):
         """
         Extracts a key (object) from a given s3:// URL.
 
@@ -520,125 +519,125 @@ class AWSJobStore(AbstractJobStore):
         if existing is True and not objExists:
             raise RuntimeError(f"Key '{keyName}' does not exist in bucket '{bucketName}'.")
         elif existing is False and objExists:
-            raise RuntimeError("Key '{keyName}' exists in bucket '{bucketName}'.")
+            raise RuntimeError(f"Key '{keyName}' exists in bucket '{bucketName}'.")
 
         if not objExists:
             obj.put()  # write an empty file
         return obj
 
     @classmethod
-    def _supportsUrl(cls, url, export=False):
+    def _supports_url(cls, url, export=False):
         return url.scheme.lower() == 's3'
 
-    def writeFile(self, localFilePath, jobStoreID=None, cleanup=False):
-        info = self.FileInfo.create(jobStoreID if cleanup else None)
-        info.upload(localFilePath, not self.config.disableJobStoreChecksumVerification)
+    def write_file(self, local_path, job_id=None, cleanup=False):
+        info = self.FileInfo.create(job_id if cleanup else None)
+        info.upload(local_path, not self.config.disableJobStoreChecksumVerification)
         info.save()
-        logger.debug("Wrote %r of from %r", info, localFilePath)
+        logger.debug("Wrote %r of from %r", info, local_path)
         return info.fileID
 
     @contextmanager
-    def writeFileStream(self, jobStoreID=None, cleanup=False, basename=None, encoding=None, errors=None):
-        info = self.FileInfo.create(jobStoreID if cleanup else None)
+    def write_file_stream(self, job_id=None, cleanup=False, basename=None, encoding=None, errors=None):
+        info = self.FileInfo.create(job_id if cleanup else None)
         with info.uploadStream(encoding=encoding, errors=errors) as writable:
             yield writable, info.fileID
         info.save()
         logger.debug("Wrote %r.", info)
 
     @contextmanager
-    def writeSharedFileStream(self, sharedFileName, isProtected=None, encoding=None, errors=None):
-        self._requireValidSharedFileName(sharedFileName)
-        info = self.FileInfo.loadOrCreate(jobStoreFileID=self._sharedFileID(sharedFileName),
+    def write_shared_file_stream(self, shared_file_name, encrypted=None, encoding=None, errors=None):
+        self._requireValidSharedFileName(shared_file_name)
+        info = self.FileInfo.loadOrCreate(jobStoreFileID=self._shared_file_id(shared_file_name),
                                           ownerID=str(self.sharedFileOwnerID),
-                                          encrypted=isProtected)
+                                          encrypted=encrypted)
         with info.uploadStream(encoding=encoding, errors=errors) as writable:
             yield writable
         info.save()
-        logger.debug("Wrote %r for shared file %r.", info, sharedFileName)
+        logger.debug("Wrote %r for shared file %r.", info, shared_file_name)
 
-    def updateFile(self, jobStoreFileID, localFilePath):
-        info = self.FileInfo.loadOrFail(jobStoreFileID)
-        info.upload(localFilePath, not self.config.disableJobStoreChecksumVerification)
+    def update_file(self, file_id, local_path):
+        info = self.FileInfo.loadOrFail(file_id)
+        info.upload(local_path, not self.config.disableJobStoreChecksumVerification)
         info.save()
-        logger.debug("Wrote %r from path %r.", info, localFilePath)
+        logger.debug("Wrote %r from path %r.", info, local_path)
 
     @contextmanager
-    def updateFileStream(self, jobStoreFileID, encoding=None, errors=None):
-        info = self.FileInfo.loadOrFail(jobStoreFileID)
+    def update_file_stream(self, file_id, encoding=None, errors=None):
+        info = self.FileInfo.loadOrFail(file_id)
         with info.uploadStream(encoding=encoding, errors=errors) as writable:
             yield writable
         info.save()
         logger.debug("Wrote %r from stream.", info)
 
-    def fileExists(self, jobStoreFileID):
-        return self.FileInfo.exists(jobStoreFileID)
+    def file_exists(self, file_id):
+        return self.FileInfo.exists(file_id)
 
-    def getFileSize(self, jobStoreFileID):
-        if not self.fileExists(jobStoreFileID):
+    def get_file_size(self, file_id):
+        if not self.file_exists(file_id):
             return 0
-        info = self.FileInfo.loadOrFail(jobStoreFileID)
+        info = self.FileInfo.loadOrFail(file_id)
         return info.getSize()
 
-    def readFile(self, jobStoreFileID, localFilePath, symlink=False):
-        info = self.FileInfo.loadOrFail(jobStoreFileID)
-        logger.debug("Reading %r into %r.", info, localFilePath)
-        info.download(localFilePath, not self.config.disableJobStoreChecksumVerification)
-        if getattr(jobStoreFileID, 'executable', False):
-            os.chmod(localFilePath, os.stat(localFilePath).st_mode | stat.S_IXUSR)
+    def read_file(self, file_id, local_path, symlink=False):
+        info = self.FileInfo.loadOrFail(file_id)
+        logger.debug("Reading %r into %r.", info, local_path)
+        info.download(local_path, not self.config.disableJobStoreChecksumVerification)
+        if getattr(file_id, 'executable', False):
+            os.chmod(local_path, os.stat(local_path).st_mode | stat.S_IXUSR)
 
     @contextmanager
-    def readFileStream(self, jobStoreFileID, encoding=None, errors=None):
-        info = self.FileInfo.loadOrFail(jobStoreFileID)
+    def read_file_stream(self, file_id, encoding=None, errors=None):
+        info = self.FileInfo.loadOrFail(file_id)
         logger.debug("Reading %r into stream.", info)
         with info.downloadStream(encoding=encoding, errors=errors) as readable:
             yield readable
 
     @contextmanager
-    def readSharedFileStream(self, sharedFileName, encoding=None, errors=None):
-        self._requireValidSharedFileName(sharedFileName)
-        jobStoreFileID = self._sharedFileID(sharedFileName)
-        info = self.FileInfo.loadOrFail(jobStoreFileID, customName=sharedFileName)
-        logger.debug("Reading %r for shared file %r into stream.", info, sharedFileName)
+    def read_shared_file_stream(self, shared_file_name, encoding=None, errors=None):
+        self._requireValidSharedFileName(shared_file_name)
+        jobStoreFileID = self._shared_file_id(shared_file_name)
+        info = self.FileInfo.loadOrFail(jobStoreFileID, customName=shared_file_name)
+        logger.debug("Reading %r for shared file %r into stream.", info, shared_file_name)
         with info.downloadStream(encoding=encoding, errors=errors) as readable:
             yield readable
 
-    def deleteFile(self, jobStoreFileID):
-        info = self.FileInfo.load(jobStoreFileID)
+    def delete_file(self, file_id):
+        info = self.FileInfo.load(file_id)
         if info is None:
-            logger.debug("File %s does not exist, skipping deletion.", jobStoreFileID)
+            logger.debug("File %s does not exist, skipping deletion.", file_id)
         else:
             info.delete()
 
-    def writeStatsAndLogging(self, statsAndLoggingString):
+    def write_logs(self, msg):
         info = self.FileInfo.create(str(self.statsFileOwnerID))
         with info.uploadStream(multipart=False) as writeable:
-            if isinstance(statsAndLoggingString, str):
+            if isinstance(msg, str):
                 # This stream is for binary data, so encode any non-encoded things
-                statsAndLoggingString = statsAndLoggingString.encode('utf-8', errors='ignore')
-            writeable.write(statsAndLoggingString)
+                msg = msg.encode('utf-8', errors='ignore')
+            writeable.write(msg)
         info.save()
 
-    def readStatsAndLogging(self, callback, readAll=False):
+    def read_logs(self, callback, read_all=False):
         itemsProcessed = 0
 
-        for info in self._readStatsAndLogging(callback, self.statsFileOwnerID):
+        for info in self._read_logs(callback, self.statsFileOwnerID):
             info._ownerID = self.readStatsFileOwnerID
             info.save()
             itemsProcessed += 1
 
-        if readAll:
-            for _ in self._readStatsAndLogging(callback, self.readStatsFileOwnerID):
+        if read_all:
+            for _ in self._read_logs(callback, self.readStatsFileOwnerID):
                 itemsProcessed += 1
 
         return itemsProcessed
 
-    def _readStatsAndLogging(self, callback, ownerId):
+    def _read_logs(self, callback, ownerId):
         items = None
         for attempt in retry_sdb():
             with attempt:
                 items = list(self.filesDomain.select(
                     consistent_read=True,
-                    query="select * from `%s` where ownerID='%s'" % (
+                    query="select * from `{}` where ownerID='{}'".format(
                         self.filesDomain.name, str(ownerId))))
         assert items is not None
         for item in items:
@@ -650,7 +649,7 @@ class AWSJobStore(AbstractJobStore):
     # TODO: Make this retry more specific?
     #  example: https://github.com/DataBiosphere/toil/issues/3378
     @retry()
-    def getPublicUrl(self, jobStoreFileID):
+    def get_public_url(self, jobStoreFileID):
         info = self.FileInfo.loadOrFail(jobStoreFileID)
         if info.content is not None:
             with info.uploadStream(allowInlining=False) as f:
@@ -680,9 +679,9 @@ class AWSJobStore(AbstractJobStore):
         url = urllib.parse.urlunsplit((scheme, netloc, path, query, fragment))
         return url
 
-    def getSharedPublicUrl(self, sharedFileName):
-        self._requireValidSharedFileName(sharedFileName)
-        return self.getPublicUrl(self._sharedFileID(sharedFileName))
+    def get_shared_public_url(self, shared_file_name):
+        self._requireValidSharedFileName(shared_file_name)
+        return self.get_public_url(self._shared_file_id(shared_file_name))
 
     def _connectSimpleDB(self):
         """
@@ -840,7 +839,7 @@ class AWSJobStore(AbstractJobStore):
                     else:
                         raise
 
-    def _newJobID(self):
+    def _new_job_id(self):
         return str(uuid.uuid4())
 
     # A dummy job ID under which all shared files are stored
@@ -852,8 +851,8 @@ class AWSJobStore(AbstractJobStore):
     # A dummy job ID under which all read stats files are stored
     readStatsFileOwnerID = uuid.UUID('e77fc3aa-d232-4255-ae04-f64ee8eb0bfa')
 
-    def _sharedFileID(self, sharedFileName):
-        return str(uuid.uuid5(self.sharedFileOwnerID, sharedFileName))
+    def _shared_file_id(self, shared_file_name):
+        return str(uuid.uuid5(self.sharedFileOwnerID, shared_file_name))
 
     @InnerClass
     class FileInfo(SDBHelper):
@@ -1276,7 +1275,11 @@ class AWSJobStore(AbstractJobStore):
                             # Save the checksum
                             info.checksum = info._finish_checksum(hasher)
 
-                            for attempt in retry_s3():
+                            for attempt in retry_s3(timeout=600):
+                                # Wait here for a bit longer if S3 breaks,
+                                # because we have been known to flake out here
+                                # in tests
+                                # (https://github.com/DataBiosphere/toil/issues/3894)
                                 with attempt:
                                     logger.debug('Attempting to complete upload...')
                                     completed = client.complete_multipart_upload(
@@ -1371,7 +1374,7 @@ class AWSJobStore(AbstractJobStore):
                 yield writable
 
             if not pipe.reader_done:
-                logger.debug('Version: {} Content: {}'.format(self.version, self.content))
+                logger.debug(f'Version: {self.version} Content: {self.content}')
                 raise RuntimeError('Escaped context manager without written data being read!')
 
             # We check our work to make sure we have exactly one of embedded
@@ -1379,11 +1382,11 @@ class AWSJobStore(AbstractJobStore):
 
             if self.content is None:
                 if not bool(self.version):
-                    logger.debug('Version: {} Content: {}'.format(self.version, self.content))
+                    logger.debug(f'Version: {self.version} Content: {self.content}')
                     raise RuntimeError('No content added and no version created')
             else:
                 if bool(self.version):
-                    logger.debug('Version: {} Content: {}'.format(self.version, self.content))
+                    logger.debug(f'Version: {self.version} Content: {self.content}')
                     raise RuntimeError('Content added and version created')
 
         def copyFrom(self, srcObj):
@@ -1577,7 +1580,7 @@ class AWSJobStore(AbstractJobStore):
                  ('checksum', r(self.checksum)),
                  ('_numContentChunks', r(self._numContentChunks)))
             return "{}({})".format(type(self).__name__,
-                                   ', '.join('%s=%s' % (k, v) for k, v in d))
+                                   ', '.join(f'{k}={v}' for k, v in d))
 
     versionings = dict(Enabled=True, Disabled=False, Suspended=None)
 
@@ -1669,6 +1672,6 @@ custom_repr = aRepr.repr
 
 class BucketLocationConflictException(Exception):
     def __init__(self, bucketRegion):
-        super(BucketLocationConflictException, self).__init__(
+        super().__init__(
             'A bucket with the same name as the jobstore was found in another region (%s). '
             'Cannot proceed as the unique bucket name is already in use.' % bucketRegion)
