@@ -21,25 +21,17 @@ import types
 from ssl import SSLError
 from typing import Optional
 
-from boto.exception import (
-    BotoServerError,
-    SDBResponseError,
-    S3ResponseError
-)
 from boto3.s3.transfer import TransferConfig
+from boto.exception import BotoServerError, S3ResponseError, SDBResponseError
 from botocore.exceptions import ClientError
 
 from toil.lib.compatibility import compat_bytes
-from toil.lib.retry import (
-    old_retry,
-    retry,
-    ErrorCondition
-)
+from toil.lib.retry import ErrorCondition, get_error_status, old_retry, retry
 
 logger = logging.getLogger(__name__)
 
 
-class SDBHelper(object):
+class SDBHelper:
     """
     A mixin with methods for storing limited amounts of binary data in an SDB item
 
@@ -117,7 +109,7 @@ class SDBHelper(object):
         """
         Turn a bytestring, or None, into SimpleDB attributes.
         """
-        if binary is None: return {u'numChunks': 0}
+        if binary is None: return {'numChunks': 0}
         assert isinstance(binary, bytes)
         assert len(binary) <= cls.maxBinarySize()
         # The use of compression is just an optimization. We can't include it in the maxValueSize
@@ -132,7 +124,7 @@ class SDBHelper(object):
         n = cls.maxValueSize
         chunks = (encoded[i:i + n] for i in range(0, len(encoded), n))
         attributes = {cls._chunkName(i): chunk for i, chunk in enumerate(chunks)}
-        attributes.update({u'numChunks': len(attributes)})
+        attributes.update({'numChunks': len(attributes)})
         return attributes
 
     @classmethod
@@ -150,7 +142,7 @@ class SDBHelper(object):
         Assuming that binaryToAttributes() is used with SDB's PutAttributes, the return value of
         this method could be used to detect the presence/absence of an item in SDB.
         """
-        return u'numChunks'
+        return 'numChunks'
 
     @classmethod
     def attributesToBinary(cls, attributes):
@@ -160,7 +152,7 @@ class SDBHelper(object):
         """
         chunks = [(int(k), v) for k, v in attributes.items() if cls._isValidChunkName(k)]
         chunks.sort()
-        numChunks = int(attributes[u'numChunks'])
+        numChunks = int(attributes['numChunks'])
         if numChunks:
             serializedJob = b''.join(v.encode() for k, v in chunks)
             compressed = base64.b64decode(serializedJob)
@@ -378,7 +370,10 @@ def connection_reset(e):
 
 
 def sdb_unavailable(e):
-    return isinstance(e, BotoServerError) and e.status in (500, 503)
+    # Since we're checking against a collection here we absolutely need an
+    # integer status code. This is probably a BotoServerError, but other 500s
+    # and 503s probably ought to be retried too.
+    return get_error_status(e) in (500, 503)
 
 
 def no_such_sdb_domain(e):
