@@ -15,17 +15,21 @@
 # 5.14.2018: copied into Toil from https://github.com/BD2KGenomics/bd2k-python-lib
 import datetime
 import re
-
 from functools import wraps
 from threading import Lock
-from typing import Dict, Any, Callable, Tuple
+from typing import Any, Callable, Dict, Tuple, TypeVar
+
+MAT = TypeVar("MAT")
+MRT = TypeVar("MRT")
 
 
-def memoize(f: Callable[..., Any]) -> Callable[..., Any]:
+def memoize(f: Callable[[MAT], MRT]) -> Callable[[MAT], MRT]:
     """
-    A decorator that memoizes a function result based on its parameters. For example, this can be
-    used in place of lazy initialization. If the decorating function is invoked by multiple
-    threads, the decorated function may be called more than once with the same arguments.
+    Memoize a function result based on its parameters using this decorator.
+
+    For example, this can be used in place of lazy initialization. If the decorating
+    function is invoked by multiple threads, the decorated function may be called
+    more than once with the same arguments.
     """
     # TODO: Recommend that f's arguments be immutable
     memory: Dict[Tuple[Any, ...], Any] = {}
@@ -42,7 +46,7 @@ def memoize(f: Callable[..., Any]) -> Callable[..., Any]:
     return new_f
 
 
-def sync_memoize(f: Callable[..., Any]) -> Callable[..., Any]:
+def sync_memoize(f: Callable[[MAT], MRT]) -> Callable[[MAT], MRT]:
     """
     Like memoize, but guarantees that decorated function is only called once, even when multiple
     threads are calling the decorating function with multiple parameters.
@@ -85,7 +89,7 @@ def parse_iso_utc(s: str) -> datetime.datetime:
     ...
     ValueError: Not a valid ISO datetime in UTC: 2016-04-27T00:28:04X
     """
-    rfc3339_datetime = re.compile('^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?(Z|[+-]\d{2}:\d{2})$')
+    rfc3339_datetime = re.compile(r'^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2})(?:\.(\d+))?(Z|[+-]\d{2}:\d{2})$')
     m = rfc3339_datetime.match(s)
     if not m:
         raise ValueError(f'Not a valid ISO datetime in UTC: {s}')
