@@ -21,25 +21,26 @@ import textwrap
 import threading
 import time
 import uuid
+from functools import wraps
+from typing import Any, Callable, Collection, Dict, Iterable, List, Optional, Set
+from urllib.parse import unquote
 
 import boto3
 import boto3.resources.base
-import botocore
-from botocore.exceptions import ClientError
 # We need these to exist as attributes we can get off of the boto object
 import boto.ec2
 import boto.iam
 import boto.vpc
-
-from typing import Any, Callable, Collection, Dict, Iterable, List, Optional, Set
-from functools import wraps
-from urllib.parse import unquote
-
-from boto.ec2.blockdevicemapping import BlockDeviceMapping as Boto2BlockDeviceMapping, BlockDeviceType as Boto2BlockDeviceType
+import botocore
+from boto.ec2.blockdevicemapping import BlockDeviceMapping as Boto2BlockDeviceMapping
+from boto.ec2.blockdevicemapping import BlockDeviceType as Boto2BlockDeviceType
+from boto.ec2.instance import Instance as Boto2Instance
 from boto.exception import BotoServerError, EC2ResponseError
 from boto.utils import get_instance_metadata
-from boto.ec2.instance import Instance as Boto2Instance
+from botocore.exceptions import ClientError
 
+from toil.lib.aws import zone_to_region
+from toil.lib.aws.ami import get_flatcar_ami
 from toil.lib.aws.utils import create_s3_bucket
 from toil.lib.conversions import human2bytes
 from toil.lib.ec2 import (a_short_time,
@@ -52,23 +53,24 @@ from toil.lib.ec2 import (a_short_time,
                           wait_instances_running,
                           wait_transition,
                           wait_until_instance_profile_arn_exists)
-from toil.lib.aws import zone_to_region
 from toil.lib.ec2nodes import InstanceType
 from toil.lib.generatedEC2Lists import E2Instances
-from toil.lib.ec2 import get_flatcar_ami
 from toil.lib.memoize import memoize
 from toil.lib.misc import truncExpBackoff
-from toil.lib.retry import (get_error_body,
-                            get_error_code,
-                            get_error_message,
-                            get_error_status,
-                            old_retry,
-                            retry,
-                            ErrorCondition)
+from toil.lib.retry import (
+    ErrorCondition,
+    get_error_body,
+    get_error_code,
+    get_error_status,
+    old_retry,
+    retry,
+)
 from toil.provisioners import NoSuchClusterException
-from toil.provisioners.abstractProvisioner import (AbstractProvisioner,
-                                                   Shape,
-                                                   ManagedNodesNotSupportedException)
+from toil.provisioners.abstractProvisioner import (
+    AbstractProvisioner,
+    ManagedNodesNotSupportedException,
+    Shape,
+)
 from toil.provisioners.aws import get_best_aws_zone
 from toil.provisioners.node import Node
 
@@ -256,7 +258,7 @@ class AWSProvisioner(AbstractProvisioner):
 
         # Call base class constructor, which will call createClusterSettings()
         # or readClusterSettings()
-        super(AWSProvisioner, self).__init__(clusterName, clusterType, zone, nodeStorage, nodeStorageOverrides)
+        super().__init__(clusterName, clusterType, zone, nodeStorage, nodeStorageOverrides)
 
         # After self.clusterName is set, generate a valid name for the S3 bucket associated with this cluster
         suffix = _S3_BUCKET_INTERNAL_SUFFIX
@@ -640,10 +642,8 @@ class AWSProvisioner(AbstractProvisioner):
     def retryPredicate(e):
         return awsRetryPredicate(e)
 
-    def destroyCluster(self):
-        """
-        Terminate instances and delete the profile and security group.
-        """
+    def destroyCluster(self) -> None:
+        """Terminate instances and delete the profile and security group."""
 
         # We should terminate the leader first in case a workflow is still running in the cluster.
         # The leader may create more instances while we're terminating the workers.
@@ -944,7 +944,7 @@ class AWSProvisioner(AbstractProvisioner):
 
     def _toNameSpace(self) -> str:
         assert isinstance(self.clusterName, (str, bytes))
-        if any((char.isupper() for char in self.clusterName)) or '_' in self.clusterName:
+        if any(char.isupper() for char in self.clusterName) or '_' in self.clusterName:
             raise RuntimeError("The cluster name must be lowercase and cannot contain the '_' "
                                "character.")
         namespace = self.clusterName
@@ -1094,7 +1094,7 @@ class AWSProvisioner(AbstractProvisioner):
     @classmethod
     def _getBoto2BlockDeviceMapping(cls, type_info: InstanceType, rootVolSize: int = 50) -> Boto2BlockDeviceMapping:
         # determine number of ephemeral drives via cgcloud-lib (actually this is moved into toil's lib
-        bdtKeys = [''] + ['/dev/xvd{}'.format(c) for c in string.ascii_lowercase[1:]]
+        bdtKeys = [''] + [f'/dev/xvd{c}' for c in string.ascii_lowercase[1:]]
         bdm = Boto2BlockDeviceMapping()
         # Change root volume size to allow for bigger Docker instances
         root_vol = Boto2BlockDeviceType(delete_on_termination=True)
@@ -1126,7 +1126,7 @@ class AWSProvisioner(AbstractProvisioner):
         }]
 
         # Get all the virtual drives we might have
-        bdtKeys = ['/dev/xvd{}'.format(c) for c in string.ascii_lowercase]
+        bdtKeys = [f'/dev/xvd{c}' for c in string.ascii_lowercase]
 
         # The first disk is already attached for us so start with 2nd.
         # Disk count is weirdly a float in our instance database, so make it an int here.
@@ -1500,8 +1500,7 @@ class AWSProvisioner(AbstractProvisioner):
         marker = None
         while True:
             result = requestor_callable(marker=marker)
-            for p in getattr(result, result_attribute_name):
-                yield p
+            yield from getattr(result, result_attribute_name)
             if result.is_truncated == 'true':
                 marker = result.marker
             else:
@@ -1524,10 +1523,8 @@ class AWSProvisioner(AbstractProvisioner):
         paginator = client.get_paginator(op_name)
 
         for page in paginator.paginate(**kwargs):
-            # Invoke it and go through the pages
-            for item in page.get(result_attribute_name, []):
-                # Yield each returned item
-                yield item
+            # Invoke it and go through the pages, yielding from them
+            yield from page.get(result_attribute_name, [])
 
     @awsRetry
     def _getRoleNames(self) -> List[str]:
@@ -1702,7 +1699,6 @@ class AWSProvisioner(AbstractProvisioner):
         except BotoServerError as e:
             if e.status == 409 and e.error_code == 'EntityAlreadyExists':
                 logger.debug('IAM role already exists. Reusing.')
-                pass
             else:
                 raise
 
