@@ -15,15 +15,12 @@ import fcntl
 import itertools
 import logging
 import os
-import stat
 import subprocess
 import sys
 import tempfile
 import time
 from abc import ABCMeta, abstractmethod
 from fractions import Fraction
-from inspect import getsource
-from textwrap import dedent
 from unittest import skipIf
 
 from toil.batchSystems.abstractBatchSystem import (AbstractBatchSystem,
@@ -34,16 +31,18 @@ from toil.batchSystems.abstractBatchSystem import (AbstractBatchSystem,
 # protected by annotations.
 from toil.batchSystems.mesos.test import MesosTestSupport
 from toil.batchSystems.parasol import ParasolBatchSystem
-from toil.batchSystems.registry import (BATCH_SYSTEM_FACTORY_REGISTRY,
-                                        BATCH_SYSTEMS,
-                                        single_machine_batch_system_factory,
-                                        addBatchSystemFactory)
-from toil.test.batchSystems.parasolTestSupport import ParasolTestSupport
+from toil.batchSystems.registry import (
+    BATCH_SYSTEM_FACTORY_REGISTRY,
+    BATCH_SYSTEMS,
+    addBatchSystemFactory,
+    restore_batch_system_plugin_state,
+    save_batch_system_plugin_state,
+)
 from toil.batchSystems.singleMachine import SingleMachineBatchSystem
 from toil.common import Config, Toil
 from toil.job import Job, JobDescription
-from toil.lib.threading import cpu_count
 from toil.lib.retry import retry_flaky_test
+from toil.lib.threading import cpu_count
 from toil.test import (ToilTest,
                        needs_aws_s3,
                        needs_fetchable_appliance,
@@ -54,9 +53,10 @@ from toil.test import (ToilTest,
                        needs_mesos,
                        needs_parasol,
                        needs_slurm,
+                       needs_tes,
                        needs_torque,
-                       slow,
-                       travis_test)
+                       slow)
+from toil.test.batchSystems.parasolTestSupport import ParasolTestSupport
 
 logger = logging.getLogger(__name__)
 
@@ -69,8 +69,34 @@ preemptable = False
 
 defaultRequirements = dict(memory=int(100e6), cores=1, disk=1000, preemptable=preemptable)
 
+class BatchSystemPluginTest(ToilTest):
+    """
+    Class for testing batch system plugin functionality.
+    """
 
-class hidden(object):
+    def setUp(self):
+        # Save plugin state so our plugin doesn't stick around after the test
+        # (and create duplicate options)
+        self.__state = save_batch_system_plugin_state()
+        super().setUp()
+
+    def tearDown(self):
+        # Restore plugin state
+        restore_batch_system_plugin_state(self.__state)
+        super().tearDown()
+
+    def testAddBatchSystemFactory(self):
+        def test_batch_system_factory():
+            # TODO: Adding the same batch system under multiple names means we
+            # can't actually create Toil options, because each version tries to
+            # add its arguments.
+            return SingleMachineBatchSystem
+
+        addBatchSystemFactory('testBatchSystem', test_batch_system_factory)
+        assert ('testBatchSystem', test_batch_system_factory) in BATCH_SYSTEM_FACTORY_REGISTRY.items()
+        assert 'testBatchSystem' in BATCH_SYSTEMS
+
+class hidden:
     """
     Hide abstract base class from unittest's test case loader
 
@@ -151,7 +177,7 @@ class hidden(object):
         def test_available_cores(self):
             self.assertTrue(cpu_count() >= numCores)
 
-        @retry_flaky_test()
+        @retry_flaky_test(prepare=[tearDown, setUp])
         def test_run_jobs(self):
             jobDesc1 = self._mockJobDescription(command='sleep 1000', jobName='test1', unitName=None,
                                                 jobStoreID='1', requirements=defaultRequirements)
@@ -193,7 +219,7 @@ class hidden(object):
 
             jobUpdateInfo = self.batchSystem.getUpdatedBatchJob(maxWait=1000)
             jobID, exitStatus, wallTime = jobUpdateInfo.jobID, jobUpdateInfo.exitStatus, jobUpdateInfo.wallTime
-            logger.info('Third job completed: {} {} {}'.format(jobID, exitStatus, wallTime))
+            logger.info(f'Third job completed: {jobID} {exitStatus} {wallTime}')
 
             # Since the first two jobs were killed, the only job in the updated jobs queue should
             # be job 3. If the first two jobs were (incorrectly) added to the queue, this will
@@ -304,21 +330,13 @@ class hidden(object):
             # prevent an endless loop, give it a few tries
             for it in range(tries):
                 running = self.batchSystem.getRunningBatchJobIDs()
-                logger.info('Running jobs now: {}'.format(running))
+                logger.info(f'Running jobs now: {running}')
                 runningIDs = list(running.keys())
                 if len(runningIDs) == numJobs:
                     break
                 time.sleep(1)
             return runningIDs
 
-        def testAddBatchSystemFactory(self):
-            def test_batch_system_factory():
-                return SingleMachineBatchSystem
-
-            addBatchSystemFactory('testBatchSystem', test_batch_system_factory)
-            assert ('testBatchSystem', test_batch_system_factory) in BATCH_SYSTEM_FACTORY_REGISTRY.items()
-            assert 'testBatchSystem' in BATCH_SYSTEMS
-
     class AbstractBatchSystemJobTest(ToilTest, metaclass=ABCMeta):
         """
         An abstract base class for batch system tests that use a full Toil workflow rather
@@ -430,6 +448,23 @@ class KubernetesBatchSystemTest(hidden.AbstractBatchSystemTest):
         return KubernetesBatchSystem(config=self.config,
                                      maxCores=numCores, maxMemory=1e9, maxDisk=2001)
 
+@needs_tes
+@needs_fetchable_appliance
+class TESBatchSystemTest(hidden.AbstractBatchSystemTest):
+    """
+    Tests against the TES batch system
+    """
+
+    def supportsWallTime(self):
+        return True
+
+    def createBatchSystem(self):
+        # Import the batch system when we know we have it.
+        # Doesn't really matter for TES right now, but someday it might.
+        from toil.batchSystems.tes import TESBatchSystem
+        return TESBatchSystem(config=self.config,
+                              maxCores=numCores, maxMemory=1e9, maxDisk=2001)
+
 
 @slow
 @needs_mesos
@@ -441,11 +476,11 @@ class MesosBatchSystemTest(hidden.AbstractBatchSystemTest, MesosTestSupport):
     @classmethod
     def createConfig(cls):
         """
-        needs to set mesosMasterAddress to localhost for testing since the default is now the
+        needs to set mesos_endpoint to localhost for testing since the default is now the
         private IP address
         """
-        config = super(MesosBatchSystemTest, cls).createConfig()
-        config.mesosMasterAddress = 'localhost:5050'
+        config = super().createConfig()
+        config.mesos_endpoint = 'localhost:5050'
         return config
 
     def supportsWallTime(self):
@@ -460,7 +495,7 @@ class MesosBatchSystemTest(hidden.AbstractBatchSystemTest, MesosTestSupport):
 
     def tearDown(self):
         self._stopMesos()
-        super(MesosBatchSystemTest, self).tearDown()
+        super().tearDown()
 
     def testIgnoreNode(self):
         self.batchSystem.ignoreNode('localhost')
@@ -494,7 +529,6 @@ def write_temp_file(s: str, temp_dir: str) -> str:
         os.close(fd)
 
 
-@travis_test
 class SingleMachineBatchSystemTest(hidden.AbstractBatchSystemTest):
     """
     Tests against the single-machine batch system
@@ -520,8 +554,8 @@ class SingleMachineBatchSystemTest(hidden.AbstractBatchSystemTest):
             #!/usr/bin/env python3
             import fcntl
             import os
-            import sys
             import signal
+            import sys
             import time
             from typing import Any
 
@@ -627,11 +661,11 @@ class MaxCoresSingleMachineBatchSystemTest(ToilTest):
 
     @classmethod
     def setUpClass(cls) -> None:
-        super(MaxCoresSingleMachineBatchSystemTest, cls).setUpClass()
+        super().setUpClass()
         logging.basicConfig(level=logging.DEBUG)
 
     def setUp(self) -> None:
-        super(MaxCoresSingleMachineBatchSystemTest, self).setUp()
+        super().setUp()
 
         temp_dir = self._createTempDir()
 
@@ -654,12 +688,12 @@ class MaxCoresSingleMachineBatchSystemTest(ToilTest):
                     fcntl.flock(fd, fcntl.LOCK_EX)
                     try:
                         s = os.read(fd, 10).decode('utf-8')
-                        value, maxValue = list(map(int, s.split(u',')))
+                        value, maxValue = list(map(int, s.split(',')))
                         value += delta
                         if value > maxValue: maxValue = value
                         os.lseek(fd, 0, 0)
                         os.ftruncate(fd, 0)
-                        os.write(fd, '{},{}'.format(value, maxValue).encode('utf-8'))
+                        os.write(fd, f'{value},{maxValue}'.encode('utf-8'))
                     finally:
                         fcntl.flock(fd, fcntl.LOCK_UN)
                 finally:
@@ -685,7 +719,7 @@ class MaxCoresSingleMachineBatchSystemTest(ToilTest):
     def scriptCommand(self) -> str:
         return ' '.join([sys.executable, self.scriptPath, self.counterPath])
 
-    @retry_flaky_test()
+    @retry_flaky_test(prepare=[tearDown, setUp])
     def test(self):
         # We'll use fractions to avoid rounding errors. Remember that not every fraction can be
         # represented as a floating point number.
@@ -772,7 +806,7 @@ def greatGrandChild(cmd):
 
 class Service(Job.Service):
     def __init__(self, cmd):
-        super(Service, self).__init__()
+        super().__init__()
         self.cmd = cmd
 
     def start(self, fileStore):
@@ -796,7 +830,7 @@ class ParasolBatchSystemTest(hidden.AbstractBatchSystemTest, ParasolTestSupport)
         return True
 
     def _createConfig(self):
-        config = super(ParasolBatchSystemTest, self)._createConfig()
+        config = super()._createConfig()
         # can't use _getTestJobStorePath since that method removes the directory
         config.jobStore = self._createTempDir('jobStore')
         return config
@@ -811,7 +845,7 @@ class ParasolBatchSystemTest(hidden.AbstractBatchSystemTest, ParasolTestSupport)
                                   maxDisk=1001)
 
     def tearDown(self):
-        super(ParasolBatchSystemTest, self).tearDown()
+        super().tearDown()
         self._stopParasol()
 
     def testBatchResourceLimits(self):
@@ -872,7 +906,7 @@ class GridEngineBatchSystemTest(hidden.AbstractGridEngineBatchSystemTest):
                                      maxDisk=1e9)
 
     def tearDown(self):
-        super(GridEngineBatchSystemTest, self).tearDown()
+        super().tearDown()
         # Cleanup GridEngine output log file from qsub
         from glob import glob
         for f in glob('toil_job*.o*'):
@@ -892,7 +926,7 @@ class SlurmBatchSystemTest(hidden.AbstractGridEngineBatchSystemTest):
                                 maxDisk=1e9)
 
     def tearDown(self):
-        super(SlurmBatchSystemTest, self).tearDown()
+        super().tearDown()
         # Cleanup 'slurm-%j.out' produced by sbatch
         from glob import glob
         for f in glob('slurm-*.out'):
@@ -919,7 +953,7 @@ class TorqueBatchSystemTest(hidden.AbstractGridEngineBatchSystemTest):
     """
 
     def _createDummyConfig(self):
-        config = super(TorqueBatchSystemTest, self)._createDummyConfig()
+        config = super()._createDummyConfig()
         # can't use _getTestJobStorePath since that method removes the directory
         config.jobStore = self._createTempDir('jobStore')
         return config
@@ -930,7 +964,7 @@ class TorqueBatchSystemTest(hidden.AbstractGridEngineBatchSystemTest):
                                      maxDisk=1e9)
 
     def tearDown(self):
-        super(TorqueBatchSystemTest, self).tearDown()
+        super().tearDown()
         # Cleanup 'toil_job-%j.out' produced by sbatch
         from glob import glob
         for f in glob('toil_job_*.[oe]*'):
@@ -950,10 +984,9 @@ class HTCondorBatchSystemTest(hidden.AbstractGridEngineBatchSystemTest):
                                    maxDisk=1e9)
 
     def tearDown(self):
-        super(HTCondorBatchSystemTest, self).tearDown()
+        super().tearDown()
 
 
-@travis_test
 class SingleMachineBatchSystemJobTest(hidden.AbstractBatchSystemJobTest):
     """
     Tests Toil workflow against the SingleMachine batch system
@@ -963,7 +996,7 @@ class SingleMachineBatchSystemJobTest(hidden.AbstractBatchSystemJobTest):
         return "single_machine"
 
     @slow
-    @retry_flaky_test()
+    @retry_flaky_test(prepare=[hidden.AbstractBatchSystemJobTest.tearDown, hidden.AbstractBatchSystemJobTest.setUp])
     def testConcurrencyWithDisk(self):
         """
         Tests that the batch system is allocating disk resources properly
@@ -1097,8 +1130,8 @@ class MesosBatchSystemJobTest(hidden.AbstractBatchSystemJobTest, MesosTestSuppor
     Tests Toil workflow against the Mesos batch system
     """
     def getOptions(self, tempDir):
-        options = super(MesosBatchSystemJobTest, self).getOptions(tempDir)
-        options.mesosMasterAddress = 'localhost:5050'
+        options = super().getOptions(tempDir)
+        options.mesos_endpoint = 'localhost:5050'
         return options
 
     def getBatchSystemName(self):
