@@ -3,9 +3,10 @@ from toil.job import Job
 
 
 def helloWorld(job, message, memory="2G", cores=2, disk="3G"):
-    job.log("Hello world, I have a message: {}".format(message))
+    job.log(f"Hello world, I have a message: {message}")
 
-if __name__=="__main__":
+
+if __name__ == "__main__":
     options = Job.Runner.getDefaultOptions("./toilWorkflowRun")
     options.logLevel = "INFO"
     options.clean = "always"
@@ -14,6 +15,7 @@ if __name__=="__main__":
     j2 = Job.wrapJobFn(helloWorld, "second or third")
     j3 = Job.wrapJobFn(helloWorld, "second or third")
     j4 = Job.wrapJobFn(helloWorld, "last")
+
     j1.addChild(j2)
     j1.addChild(j3)
     j1.addFollowOn(j4)
