@@ -5,21 +5,25 @@ from toil.job import Job, PromisedRequirement
 
 
 def parentJob(job):
-    downloadJob = Job.wrapJobFn(stageFn, "File://"+os.path.realpath(__file__), cores=0.1, memory='32M', disk='1M')
+    downloadJob = Job.wrapJobFn(stageFn, "file://" + os.path.realpath(__file__), cores=0.1, memory='32M', disk='1M')
     job.addChild(downloadJob)
 
-    analysis = Job.wrapJobFn(analysisJob, fileStoreID=downloadJob.rv(0),
+    analysis = Job.wrapJobFn(analysisJob,
+                             fileStoreID=downloadJob.rv(0),
                              disk=PromisedRequirement(downloadJob.rv(1)))
     job.addFollowOn(analysis)
 
+
 def stageFn(job, url, cores=1):
-    importedFile = job.fileStore.importFile(url)
+    importedFile = job.fileStore.import_file(url)
     return importedFile, importedFile.size
 
+
 def analysisJob(job, fileStoreID, cores=2):
     # now do some analysis on the file
     pass
 
+
 if __name__ == "__main__":
     options = Job.Runner.getDefaultOptions("./toilWorkflowRun")
     options.logLevel = "INFO"
