@@ -16,15 +16,13 @@ import datetime
 import logging
 import random
 import time
-import types
 import uuid
 from collections import defaultdict
 from contextlib import contextmanager
 from queue import Empty, Queue
 from threading import Event, Thread
-from typing import Set, List, Optional, Tuple
-
-from mock import MagicMock
+from typing import List, Optional, Set, Tuple
+from unittest.mock import MagicMock
 
 from toil.batchSystems.abstractBatchSystem import (AbstractBatchSystem,
                                                    AbstractScalableBatchSystem,
@@ -32,14 +30,13 @@ from toil.batchSystems.abstractBatchSystem import (AbstractBatchSystem,
 from toil.common import Config, defaultTargetTime
 from toil.job import JobDescription
 from toil.lib.conversions import human2bytes as h2b
-from toil.provisioners import parse_node_types
 from toil.provisioners.abstractProvisioner import AbstractProvisioner, Shape
 from toil.provisioners.clusterScaler import (BinPackedFit,
                                              ClusterScaler,
                                              NodeReservation,
                                              ScalerThread)
 from toil.provisioners.node import Node
-from toil.test import ToilTest, slow, travis_test
+from toil.test import ToilTest, slow
 
 logger = logging.getLogger(__name__)
 
@@ -73,7 +70,6 @@ class BinPackingTest(ToilTest):
         self.node_shapes_for_testing = [c4_8xlarge_preemptable, r3_8xlarge]
         self.bpf = BinPackedFit(self.node_shapes_for_testing)
 
-    @travis_test
     def testPackingOneShape(self):
         """Pack one shape and check that the resulting reservations look sane."""
         self.bpf.nodeReservations[c4_8xlarge_preemptable] = [NodeReservation(c4_8xlarge_preemptable)]
@@ -95,7 +91,6 @@ class BinPackingTest(ToilTest):
                                  disk=h2b('100G'),
                                  preemptable=True)]])
 
-    @travis_test
     def testSorting(self):
         """
         Test that sorting is correct: preemptable, then memory, then cores, then disk,
@@ -109,7 +104,6 @@ class BinPackingTest(ToilTest):
                              c4_8xlarge, c4_8xlarge, c4_8xlarge,
                              r3_8xlarge, r3_8xlarge, r3_8xlarge]
 
-    @travis_test
     def testAddingInitialNode(self):
         """Pack one shape when no nodes are available and confirm that we fit one node properly."""
         self.bpf.addJobShape(Shape(wallTime=1000,
@@ -129,7 +123,6 @@ class BinPackingTest(ToilTest):
                                  disk=h2b('100G'),
                                  preemptable=True)]])
 
-    @travis_test
     def testLowTargetTime(self):
         """
         Test that a low targetTime (0) parallelizes jobs aggressively (1000 queued jobs require
@@ -151,7 +144,6 @@ class BinPackingTest(ToilTest):
                                               globalTargetTime=0)
         self.assertEqual(allocation, {t2_micro: 1000})
 
-    @travis_test
     def testHighTargetTime(self):
         """
         Test that a high targetTime (3600 seconds) maximizes packing within the targetTime.
@@ -172,7 +164,6 @@ class BinPackingTest(ToilTest):
                                               globalTargetTime=3600)
         self.assertEqual(allocation, {t2_micro: 84})
 
-    @travis_test
     def testZeroResourceJobs(self):
         """
         Test that jobs requiring zero cpu/disk/mem pack first, regardless of targetTime.
@@ -191,7 +182,6 @@ class BinPackingTest(ToilTest):
                                               globalTargetTime=0)
         self.assertEqual(allocation, {t2_micro: 1})
 
-    @travis_test
     def testLongRunningJobs(self):
         """
         Test that jobs with long run times (especially service jobs) are aggressively parallelized.
@@ -225,7 +215,6 @@ class BinPackingTest(ToilTest):
                                    preemptable=False))
         return bpf.getRequiredNodes()
 
-    @travis_test
     def testPathologicalCase(self):
         """Test a pathological case where only one node can be requested to fit months' worth of jobs.
 
@@ -251,7 +240,6 @@ class BinPackingTest(ToilTest):
         # Hopefully we didn't assign just one node to cover all those jobs.
         self.assertNotEqual(self.bpf.getRequiredNodes(), {r3_8xlarge: 1, c4_8xlarge_preemptable: 0})
 
-    @travis_test
     def testJobTooLargeForAllNodes(self):
         """
         If a job is too large for all node types, the scaler should print a
@@ -268,7 +256,7 @@ class BinPackingTest(ToilTest):
 
 class ClusterScalerTest(ToilTest):
     def setUp(self):
-        super(ClusterScalerTest, self).setUp()
+        super().setUp()
         self.config = Config()
         self.config.targetTime = 1800
         self.config.nodeTypes = [r3_8xlarge, c4_8xlarge_preemptable]
@@ -280,7 +268,6 @@ class ClusterScalerTest(ToilTest):
         # Pretend that Shapes are actually strings we can use for instance type names.
         self.provisioner.setAutoscaledNodeTypes([({t}, None) for t in self.config.nodeTypes])
 
-    @travis_test
     def testRounding(self):
         """
         Test to make sure the ClusterScaler's rounding rounds properly.
@@ -313,7 +300,6 @@ class ClusterScalerTest(ToilTest):
         self.assertEqual(scaler._round(-15.5), -16)
         self.assertEqual(scaler._round(123456789101112.5), 123456789101113)
 
-    @travis_test
     def testMaxNodes(self):
         """
         Set the scaler to be very aggressive, give it a ton of jobs, and
@@ -337,7 +323,6 @@ class ClusterScalerTest(ToilTest):
         self.assertEqual(estimatedNodeCounts[r3_8xlarge], 2)
         self.assertEqual(estimatedNodeCounts[c4_8xlarge_preemptable], 3)
 
-    @travis_test
     def testMinNodes(self):
         """
         Without any jobs queued, the scaler should still estimate "minNodes" nodes.
@@ -350,7 +335,6 @@ class ClusterScalerTest(ToilTest):
         self.assertEqual(estimatedNodeCounts[r3_8xlarge], 2)
         self.assertEqual(estimatedNodeCounts[c4_8xlarge_preemptable], 3)
 
-    @travis_test
     def testPreemptableDeficitResponse(self):
         """
         When a preemptable deficit was detected by a previous run of the
@@ -387,7 +371,6 @@ class ClusterScalerTest(ToilTest):
         # properly: 0.5 * 5 (preemptableCompensation * the deficit) = 3 (rounded up).
         self.assertEqual(estimatedNodeCounts[self.provisioner.node_shapes_for_testing[1]], 3)
 
-    @travis_test
     def testPreemptableDeficitIsSet(self):
         """
         Make sure that updateClusterSize sets the preemptable deficit if
@@ -418,7 +401,6 @@ class ClusterScalerTest(ToilTest):
         scaler.updateClusterSize(estimatedNodeCounts)
         self.assertEqual(scaler.preemptableNodeDeficit[c4_8xlarge], 0)
 
-    @travis_test
     def testNoLaunchingIfDeltaAlreadyMet(self):
         """
         Check that the scaler doesn't try to launch "0" more instances if
@@ -442,7 +424,6 @@ class ClusterScalerTest(ToilTest):
                          "The scaler didn't unignore an ignored node when "
                          "scaling up")
 
-    @travis_test
     def testBetaInertia(self):
         # This is really high, but makes things easy to calculate.
         self.config.betaInertia = 0.5
@@ -650,7 +631,7 @@ class MockBatchSystemAndProvisioner(AbstractScalableBatchSystem, AbstractProvisi
     Mimics a job batcher, provisioner and scalable batch system
     """
     def __init__(self, config, secondsPerJob):
-        super(MockBatchSystemAndProvisioner, self).__init__(clusterName='clusterName', clusterType='mesos')
+        super().__init__(clusterName='clusterName', clusterType='mesos')
         # To mimic parallel preemptable and non-preemptable queues
         # for jobs we create two parallel instances of the following class
         self.config = config
@@ -746,7 +727,7 @@ class MockBatchSystemAndProvisioner(AbstractScalableBatchSystem, AbstractProvisi
                                                                                "cores": jobShape.cores,
                                                                                "disk": jobShape.disk,
                                                                                "preemptable": preemptable},
-                                                                 jobName='job{}'.format(self.totalJobs))
+                                                                 jobName=f'job{self.totalJobs}')
         self.jobQueue.put(jobID)
 
     # JobBatcher functionality
@@ -790,7 +771,7 @@ class MockBatchSystemAndProvisioner(AbstractScalableBatchSystem, AbstractProvisi
                       vpcSubnet=None, leaderStorage=50, nodeStorage=50, botoPath=None, **kwargs):
         pass
 
-    def destroyCluster(self):
+    def destroyCluster(self) -> None:
         pass
 
     def getLeader(self):
@@ -811,7 +792,7 @@ class MockBatchSystemAndProvisioner(AbstractScalableBatchSystem, AbstractProvisi
     def _addNodes(self, numNodes, nodeType: str, preemptable=False):
         nodeShape = self.getNodeShape(nodeType=nodeType, preemptable=preemptable)
 
-        class Worker(object):
+        class Worker:
             def __init__(self, jobQueue, updatedJobsQueue, secondsPerJob):
                 self.busyEvent = Event()
                 self.stopEvent = Event()
