@@ -14,20 +14,19 @@
 import os
 import signal
 import time
-import psutil
 from abc import ABCMeta
 from uuid import uuid4
 
+import psutil
+
 from toil.job import Job
 from toil.leader import FailedJobsException
 from toil.lib.threading import cpu_count
-from toil.test import ToilTest, slow, travis_test
+from toil.test import ToilTest, slow
 
 
 class DeferredFunctionTest(ToilTest, metaclass=ABCMeta):
-    """
-    Test the deferred function system.
-    """
+    """Test the deferred function system."""
     # This determines what job store type to use.
     jobStoreType = 'file'
 
@@ -35,15 +34,15 @@ class DeferredFunctionTest(ToilTest, metaclass=ABCMeta):
         if self.jobStoreType == 'file':
             return self._getTestJobStorePath()
         elif self.jobStoreType == 'aws':
-            return 'aws:%s:cache-tests-%s' % (self.awsRegion(), uuid4())
+            return f'aws:{self.awsRegion()}:cache-tests-{uuid4()}'
         elif self.jobStoreType == 'google':
             projectID = os.getenv('TOIL_GOOGLE_PROJECTID')
-            return 'google:%s:cache-tests-%s' % (projectID, str(uuid4()))
+            return 'google:{}:cache-tests-{}'.format(projectID, str(uuid4()))
         else:
             raise RuntimeError('Illegal job store type.')
 
     def setUp(self):
-        super(DeferredFunctionTest, self).setUp()
+        super().setUp()
         testDir = self._createTempDir()
         self.options = Job.Runner.getDefaultOptions(self._getTestJobStore())
         self.options.logLevel = 'INFO'
@@ -52,7 +51,6 @@ class DeferredFunctionTest(ToilTest, metaclass=ABCMeta):
         self.options.logFile = os.path.join(testDir, 'logFile')
 
     # Tests for the various defer possibilities
-    @travis_test
     def testDeferredFunctionRunsWithMethod(self):
         """
         Refer docstring in _testDeferredFunctionRuns.
@@ -60,7 +58,6 @@ class DeferredFunctionTest(ToilTest, metaclass=ABCMeta):
         """
         self._testDeferredFunctionRuns(_writeNonLocalFilesMethod)
 
-    @travis_test
     def testDeferredFunctionRunsWithClassMethod(self):
         """
         Refer docstring in _testDeferredFunctionRuns.
@@ -68,7 +65,6 @@ class DeferredFunctionTest(ToilTest, metaclass=ABCMeta):
         """
         self._testDeferredFunctionRuns(_writeNonLocalFilesClassMethod)
 
-    @travis_test
     def testDeferredFunctionRunsWithLambda(self):
         """
         Refer docstring in _testDeferredFunctionRuns.
@@ -168,7 +164,6 @@ class DeferredFunctionTest(ToilTest, metaclass=ABCMeta):
         except FailedJobsException as e:
             pass
 
-    @travis_test
     def testBatchSystemCleanupCanHandleWorkerDeaths(self):
         """
         Create a non-local files. Create a job that registers a deferred job to delete the file
@@ -289,7 +284,7 @@ def _testNewJobsCanHandleOtherJobDeaths_B(job, files):
     while os.path.exists(files[0]):
         time.sleep(0.5)
     # Get the pid of _testNewJobsCanHandleOtherJobDeaths_A and wait for it to truly be dead.
-    with open(files[1], 'r') as fileHandle:
+    with open(files[1]) as fileHandle:
         pid = int(fileHandle.read())
     assert pid > 0
     while psutil.pid_exists(pid):
@@ -310,7 +305,7 @@ def _testNewJobsCanHandleOtherJobDeaths_C(job, files, expectedResult):
         assert os.path.exists(testFile) is expectedResult
 
 
-class _deleteMethods(object):
+class _deleteMethods:
     @staticmethod
     def _deleteFileMethod(nonLocalFile, nlf=None):
         """
