@@ -26,12 +26,16 @@ import stat
 import sys
 import time
 import traceback
-
 from contextlib import contextmanager
 from typing import Any, Callable, Iterator, List, Optional
 
 from toil import logProcessContext
-from toil.common import Toil, Config, safeUnpickleFromStream
+from toil.common import Config, Toil, safeUnpickleFromStream
+from toil.cwl.utils import (
+    CWL_INTERNAL_JOBS,
+    CWL_UNSUPPORTED_REQUIREMENT_EXCEPTION,
+    CWL_UNSUPPORTED_REQUIREMENT_EXIT_CODE,
+)
 from toil.deferred import DeferredFunctionManager
 from toil.fileStores.abstractFileStore import AbstractFileStore
 from toil.job import CheckpointJobDescription, Job, JobDescription
@@ -42,19 +46,15 @@ from toil.lib.resources import (get_total_cpu_time,
                                 get_total_cpu_time_and_memory_usage)
 from toil.statsAndLogging import configure_root_logger, set_log_level
 
-try:
-    from toil.cwl.cwltoil import (CWL_INTERNAL_JOBS,
-                                  CWL_UNSUPPORTED_REQUIREMENT_EXIT_CODE,
-                                  CWL_UNSUPPORTED_REQUIREMENT_EXCEPTION)
-except ImportError:
-    # CWL extra not installed
-    CWL_INTERNAL_JOBS = ()
-    CWL_UNSUPPORTED_REQUIREMENT_EXIT_CODE = None
-    CWL_UNSUPPORTED_REQUIREMENT_EXCEPTION = type(None)
-
 logger = logging.getLogger(__name__)
 
 
+class StatsDict(MagicExpando):
+    """Subclass of MagicExpando for type-checking purposes."""
+
+    jobs: List[str]
+
+
 def nextChainable(predecessor: JobDescription, jobStore: AbstractJobStore, config: Config) -> Optional[JobDescription]:
     """
     Returns the next chainable job's JobDescription after the given predecessor
@@ -96,7 +96,7 @@ def nextChainable(predecessor: JobDescription, jobStore: AbstractJobStore, confi
     successorID = next(iter(jobs))
 
     # Load the successor JobDescription
-    successor = jobStore.load(successorID)
+    successor = jobStore.load_job(successorID)
 
     #We check the requirements of the successor to see if we can run it
     #within the current worker
@@ -189,7 +189,7 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
     ##########################################
 
     #First load the environment for the job.
-    with jobStore.readSharedFileStream("environment.pickle") as fileHandle:
+    with jobStore.read_shared_file_stream("environment.pickle") as fileHandle:
         environment = safeUnpickleFromStream(fileHandle)
     env_reject = {
         "TMPDIR",
@@ -224,6 +224,7 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
     #Setup the temporary directories.
     ##########################################
     # Dir to put all this worker's temp files in.
+    assert config.workflowID
     toilWorkflowDir = Toil.getLocalWorkflowDir(config.workflowID, config.workDir)
     localWorkerTempDir = make_public_dir(in_directory=toilWorkflowDir)
     os.chmod(localWorkerTempDir, 0o755)
@@ -279,46 +280,48 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
 
     debugging = logging.getLogger().isEnabledFor(logging.DEBUG)
     ##########################################
-    #Worker log file trapped from here on in
+    # Worker log file trapped from here on in
     ##########################################
 
     jobAttemptFailed = False
     failure_exit_code = 1
-    statsDict = MagicExpando()
+    statsDict = StatsDict()  # type: ignore[no-untyped-call]
     statsDict.jobs = []
     statsDict.workers.logsToMaster = []
-    blockFn = lambda : True
+
+    def blockFn() -> bool:
+        return True
     listOfJobs = [jobName]
     job = None
     try:
 
-        #Put a message at the top of the log, just to make sure it's working.
+        # Put a message at the top of the log, just to make sure it's working.
         logger.info("---TOIL WORKER OUTPUT LOG---")
         sys.stdout.flush()
 
         logProcessContext(config)
 
         ##########################################
-        #Connect to the deferred function system
+        # Connect to the deferred function system
         ##########################################
         deferredFunctionManager = DeferredFunctionManager(toilWorkflowDir)
 
         ##########################################
-        #Load the JobDescription
+        # Load the JobDescription
         ##########################################
 
-        jobDesc = jobStore.load(jobStoreID)
+        jobDesc = jobStore.load_job(jobStoreID)
         listOfJobs[0] = str(jobDesc)
         logger.debug("Parsed job description")
 
         ##########################################
-        #Cleanup from any earlier invocation of the job
+        # Cleanup from any earlier invocation of the job
         ##########################################
 
-        if jobDesc.command == None:
+        if jobDesc.command is None:
             logger.debug("Job description has no body to run.")
             # Cleanup jobs already finished
-            predicate = lambda jID: jobStore.exists(jID)
+            predicate = lambda jID: jobStore.job_exists(jID)
             jobDesc.filterSuccessors(predicate)
             jobDesc.filterServiceHosts(predicate)
             logger.debug("Cleaned up any references to completed successor jobs")
@@ -326,10 +329,10 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
         # This cleans the old log file which may
         # have been left if the job is being retried after a job failure.
         oldLogFile = jobDesc.logJobStoreFileID
-        if oldLogFile != None:
+        if oldLogFile is not None:
             jobDesc.logJobStoreFileID = None
-            jobStore.update(jobDesc) #Update first, before deleting any files
-            jobStore.deleteFile(oldLogFile)
+            jobStore.update_job(jobDesc)  # Update first, before deleting any files
+            jobStore.delete_file(oldLogFile)
 
         ##########################################
         # If a checkpoint exists, restart from the checkpoint
@@ -352,7 +355,7 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
             else:
                 logger.debug("The checkpoint jobs seems to have completed okay, removing any checkpoint files to delete.")
                 #Delete any remnant files
-                list(map(jobStore.deleteFile, list(filter(jobStore.fileExists, jobDesc.checkpointFilesToDelete))))
+                list(map(jobStore.delete_file, list(filter(jobStore.file_exists, jobDesc.checkpointFilesToDelete))))
 
         ##########################################
         #Setup the stats, if requested
@@ -509,6 +512,17 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
             # and it needs to inform its caller.
             failure_exit_code = CWL_UNSUPPORTED_REQUIREMENT_EXIT_CODE
         AbstractFileStore._terminateEvent.set()
+    finally:
+        try:
+            import cwltool.main
+
+            cwltool.main._terminate_processes()
+        except (ImportError, ModuleNotFoundError):
+            pass
+        except Exception as e:
+            logger.debug("cwltool.main._terminate_processess exception: %s", (e))
+            raise e
+
 
     ##########################################
     #Wait for the asynchronous chain of writes/updates to finish
@@ -526,7 +540,7 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
 
         # Clobber any garbage state we have for this job from failing with
         # whatever good state is still stored in the JobStore
-        jobDesc = jobStore.load(jobStoreID)
+        jobDesc = jobStore.load_job(jobStoreID)
         # Remember that we failed
         jobAttemptFailed = True
 
@@ -566,9 +580,11 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
     # interpret seek offsets in characters for us). TODO: We may get invalid or
     # just different Unicode by breaking up a character at the boundary!
     if jobAttemptFailed and redirectOutputToLogFile:
-        jobDesc.logJobStoreFileID = jobStore.getEmptyFileStoreID(jobDesc.jobStoreID, cleanup=True)
+        jobDesc.logJobStoreFileID = logJobStoreFileID = jobStore.getEmptyFileStoreID(
+            jobDesc.jobStoreID, cleanup=True
+        )
         jobDesc.chainedJobs = listOfJobs
-        with jobStore.updateFileStream(jobDesc.logJobStoreFileID) as w:
+        with jobStore.update_file_stream(logJobStoreFileID) as w:
             with open(tempWorkerLogPath, 'rb') as f:
                 if os.path.getsize(tempWorkerLogPath) > logFileByteReportLimit !=0:
                     if logFileByteReportLimit > 0:
@@ -578,7 +594,7 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
                 # Dump the possibly-invalid-Unicode bytes into the log file
                 w.write(f.read()) # TODO load file using a buffer
         # Commit log file reference back to JobStore
-        jobStore.update(jobDesc)
+        jobStore.update_job(jobDesc)
 
     elif ((debugging or (config.writeLogsFromAllJobs and not jobName.startswith(CWL_INTERNAL_JOBS)))
           and redirectOutputToLogFile):  # write log messages
@@ -595,7 +611,7 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
         statsDict.logs.messages = logMessages
 
     if (debugging or config.stats or statsDict.workers.logsToMaster) and not jobAttemptFailed:  # We have stats/logging to report back
-        jobStore.writeStatsAndLogging(json.dumps(statsDict, ensure_ascii=True))
+        jobStore.write_logs(json.dumps(statsDict, ensure_ascii=True))
 
     # Remove the temp dir
     cleanUp = config.cleanWorkDir
@@ -613,15 +629,14 @@ def workerScript(jobStore: AbstractJobStore, config: Config, jobName: str, jobSt
                 os.chmod(os.path.dirname(path),  stat.S_IRUSR | stat.S_IWUSR | stat.S_IXUSR)
             except PermissionError as e:
                 logger.error('Could not set permissions on %s to allow cleanup of %s: %s', os.path.dirname(path), path, e)
-                pass
         shutil.rmtree(localWorkerTempDir, onerror=make_parent_writable)
 
     # This must happen after the log file is done with, else there is no place to put the log
     if (not jobAttemptFailed) and jobDesc.command == None and next(jobDesc.successorsAndServiceHosts(), None) is None:
         # We can now safely get rid of the JobDescription, and all jobs it chained up
         for otherID in jobDesc.jobsToDelete:
-            jobStore.delete(otherID)
-        jobStore.delete(jobDesc.jobStoreID)
+            jobStore.delete_job(otherID)
+        jobStore.delete_job(str(jobDesc.jobStoreID))
 
     if jobAttemptFailed:
         return failure_exit_code
